@@ -121,32 +121,32 @@ void increment_counters_from_bitmap(count_t * counters,
                                     unsigned char * bitmap,
                                     unsigned int totalbits)
 {
-  const vector unsigned char c1 =
+  const __vector unsigned char c1 =
     { 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0 };
-  const vector unsigned char c2 =
+  const __vector unsigned char c2 =
     { 0xfe, 0xfd, 0xfb, 0xf7, 0xef, 0xdf, 0xbf, 0x7f,
       0xfe, 0xfd, 0xfb, 0xf7, 0xef, 0xdf, 0xbf, 0x7f };
-  const vector unsigned char c3 =
+  const __vector unsigned char c3 =
     { 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
       0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };
 
   unsigned short * p = (unsigned short *)(bitmap);
-  vector signed short * q = (vector signed short *) (counters);
+  __vector signed short * q = (__vector signed short *) (counters);
   int r = (totalbits + 15) / 16;
 
   for(int j=0; j<r; j++)
     {
-      vector unsigned char r0, r1, r2;
-      vector __bool char r3;
-      vector signed short r4, r5;
+      __vector unsigned char r0, r1, r2;
+      __vector __bool char r3;
+      __vector signed short r4, r5;
 
-      r0 = * (vector unsigned char *) p;
+      memcpy(&r0, p, 2);
       p++;
       r1 = vec_perm(r0, r0, c1);
       r2 = vec_or(r1, c2);
       r3 = vec_cmpeq(r2, c3);
-      r4 = (vector signed short) vec_unpackl(r3);
-      r5 = (vector signed short) vec_unpackh(r3);
+      r4 = (__vector signed short) vec_unpackl(r3);
+      r5 = (__vector signed short) vec_unpackh(r3);
       *q = vec_subs(*q, r4);
       q++;
       *q = vec_subs(*q, r5);
@@ -195,8 +195,8 @@ void increment_counters_from_bitmap_sse2(count_t * counters,
   const __m128i c3 =
     _mm_set_epi32(0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff);
 
-  unsigned short * p = (unsigned short *)(bitmap);
-  __m128i * q = (__m128i *)(counters);
+  auto * p = (unsigned short *)(bitmap);
+  auto * q = (__m128i *)(counters);
   int r = (totalbits + 15) / 16;
 
   for(int j=0; j<r; j++)
