@@ -72,12 +72,16 @@ int dbhash_seqcmp(char * a, char * b, uint64_t n)
   char * q = b;
 
   if (n <= 0)
-    return 0;
+    {
+      return 0;
+    }
 
   while ((n-- > 0) && (chrmap_4bit[(int)(*p)] == chrmap_4bit[(int)(*q)]))
     {
       if ((n == 0) || (*p == 0) || (*q == 0))
-        break;
+        {
+          break;
+        }
       p++;
       q++;
     }
@@ -110,14 +114,14 @@ void dbhash_open(uint64_t maxelements)
 void dbhash_close()
 {
   bitmap_free(dbhash_bitmap);
-  dbhash_bitmap = 0;
+  dbhash_bitmap = nullptr;
   xfree(dbhash_table);
-  dbhash_table = 0;
+  dbhash_table = nullptr;
 }
 
 int64_t dbhash_search_first(char * seq,
-                        uint64_t seqlen,
-                        struct dbhash_search_info_s * info)
+                            uint64_t seqlen,
+                            struct dbhash_search_info_s * info)
 {
 
   uint64_t hash = hash_cityhash64(seq, seqlen);
@@ -140,9 +144,13 @@ int64_t dbhash_search_first(char * seq,
   info->index = index;
 
   if (bitmap_get(dbhash_bitmap, index))
-    return bp->seqno;
+    {
+      return bp->seqno;
+    }
   else
-    return -1;
+    {
+      return -1;
+    }
 }
 
 int64_t dbhash_search_next(struct dbhash_search_info_s * info)
@@ -166,9 +174,13 @@ int64_t dbhash_search_next(struct dbhash_search_info_s * info)
   info->index = index;
 
   if (bitmap_get(dbhash_bitmap, index))
-    return bp->seqno;
+    {
+      return bp->seqno;
+    }
   else
-    return -1;
+    {
+      return -1;
+    }
 }
 
 void dbhash_add(char * seq, uint64_t seqlen, uint64_t seqno)
@@ -177,7 +189,9 @@ void dbhash_add(char * seq, uint64_t seqlen, uint64_t seqno)
 
   int64_t ret = dbhash_search_first(seq, seqlen, & info);
   while (ret >= 0)
-    ret = dbhash_search_next(&info);
+    {
+      ret = dbhash_search_next(&info);
+    }
 
   bitmap_set(dbhash_bitmap, info.index);
   struct dbhash_bucket_s * bp = dbhash_table + info.index;
