@@ -68,42 +68,60 @@ struct bucket
   unsigned int seqno_first;
   unsigned int seqno_last;
   unsigned int size;
+  unsigned int count;
   bool deleted;
   char * header;
   char * seq;
+  char * qual;
 };
 
 int derep_compare_prefix(const void * a, const void * b)
 {
-  struct bucket * x = (struct bucket *) a;
-  struct bucket * y = (struct bucket *) b;
+  auto * x = (struct bucket *) a;
+  auto * y = (struct bucket *) b;
 
   /* highest abundance first, then by label, otherwise keep order */
 
   if (x->deleted > y->deleted)
-    return +1;
+    {
+      return +1;
+    }
   else if (x->deleted < y->deleted)
-    return -1;
+    {
+      return -1;
+    }
   else
     {
       if (x->size < y->size)
-        return +1;
+        {
+          return +1;
+        }
       else if (x->size > y->size)
-        return -1;
+        {
+          return -1;
+        }
       else
         {
           int r = strcmp(db_getheader(x->seqno_first),
                          db_getheader(y->seqno_first));
           if (r != 0)
-            return r;
+            {
+              return r;
+            }
           else
             {
               if (x->seqno_first < y->seqno_first)
-                return -1;
+                {
+                  return -1;
+                }
               else if (x->seqno_first > y->seqno_first)
-                return +1;
+                {
+                  return +1;
+                }
               else
-                return 0;
+                {
+                  return 0;
+                }
             }
         }
     }
@@ -111,36 +129,54 @@ int derep_compare_prefix(const void * a, const void * b)
 
 int derep_compare_full(const void * a, const void * b)
 {
-  struct bucket * x = (struct bucket *) a;
-  struct bucket * y = (struct bucket *) b;
+  auto * x = (struct bucket *) a;
+  auto * y = (struct bucket *) b;
 
   /* highest abundance first, then by label, otherwise keep order */
 
   if (x->deleted > y->deleted)
-    return +1;
+    {
+      return +1;
+    }
   else if (x->deleted < y->deleted)
-    return -1;
+    {
+      return -1;
+    }
   else
     {
       if (x->size < y->size)
-        return +1;
+        {
+          return +1;
+        }
       else if (x->size > y->size)
-        return -1;
+        {
+          return -1;
+        }
       else
         {
           if (x->size == 0)
-            return 0;
+            {
+              return 0;
+            }
           int r = strcmp(x->header, y->header);
           if (r != 0)
-            return r;
+            {
+              return r;
+            }
           else
             {
               if (x->seqno_first < y->seqno_first)
-                return -1;
+                {
+                  return -1;
+                }
               else if (x->seqno_first > y->seqno_first)
-                return +1;
+                {
+                  return +1;
+                }
               else
-                return 0;
+                {
+                  return 0;
+                }
             }
         }
     }
@@ -152,12 +188,16 @@ int seqcmp(char * a, char * b, int n)
   char * q = b;
 
   if (n <= 0)
-    return 0;
+    {
+      return 0;
+    }
 
   while ((n-- > 0) && (chrmap_4bit[(int)(*p)] == chrmap_4bit[(int)(*q)]))
     {
       if ((n == 0) || (*p == 0) || (*q == 0))
-        break;
+        {
+          break;
+        }
       p++;
       q++;
     }
@@ -181,7 +221,7 @@ void rehash(struct bucket * * hashtableref, int64_t alloc_clusters)
   uint64_t new_hashtablesize = 2 * old_hashtablesize;
   uint64_t new_hash_mask = new_hashtablesize - 1;
 
-  struct bucket * new_hashtable =
+  auto * new_hashtable =
     (struct bucket *) xmalloc(sizeof(bucket) * new_hashtablesize);
   memset(new_hashtable, 0, sizeof(bucket) * new_hashtablesize);
 
@@ -193,7 +233,9 @@ void rehash(struct bucket * * hashtableref, int64_t alloc_clusters)
         {
           uint64_t k = old_bp->hash & new_hash_mask;
           while (new_hashtable[k].size)
-            k = (k + 1) & new_hash_mask;
+            {
+              k = (k + 1) & new_hash_mask;
+            }
           struct bucket * new_bp = new_hashtable + k;
 
           * new_bp = * old_bp;
@@ -204,36 +246,128 @@ void rehash(struct bucket * * hashtableref, int64_t alloc_clusters)
   * hashtableref = new_hashtable;
 }
 
+inline double convert_q_to_p(int q)
+{
+  int x = q - opt_fastq_ascii;
+  if (x < 2)
+    {
+      return 0.75;
+    }
+  else
+    {
+      return exp10(-x/10.0);
+    }
+}
+
+inline int convert_p_to_q(double p)
+{
+  // int q = round(-10.0 * log10(p));
+  int q = int(-10.0 * log10(p));
+  q = MIN(q, opt_fastq_qmaxout);
+  q = MAX(q, opt_fastq_qminout);
+  return opt_fastq_asciiout + q;
+}
+
 void derep(char * input_filename, bool use_header)
 {
   /* dereplicate full length sequences, optionally require identical headers */
 
+  /*
+    derep_fulllength output options: --output, --uc (only FASTA, depreciated)
+    fastx_uniques output options: --fastaout, --fastqout, --uc, --tabbedout
+  */
+
   show_rusage();
 
-  FILE * fp_output = 0;
-  FILE * fp_uc = 0;
+  fastx_handle h = fastx_open(input_filename);
 
-  if (opt_output)
+  if (!h)
     {
-      fp_output = fopen_output(opt_output);
-      if (!fp_output)
-        fatal("Unable to open output file for writing");
+      fatal("Unrecognized input file type (not proper FASTA or FASTQ format)");
+    }
+
+  if (! fastx_is_empty(h))
+    {
+      if (fastx_is_fastq(h))
+        {
+          if (!opt_fastx_uniques)
+            fatal("FASTQ input is only allowed with the fastx_uniques command");
+        }
+      else
+        {
+          if (opt_fastqout)
+            fatal("Cannot write FASTQ output when input file is not in FASTQ format");
+          if (opt_tabbedout)
+            fatal("Cannot write tab separated output file when input file is not in FASTQ format");
+        }
+    }
+
+  FILE * fp_fastaout = nullptr;
+  FILE * fp_fastqout = nullptr;
+  FILE * fp_uc = nullptr;
+  FILE * fp_tabbedout = nullptr;
+
+  if (opt_fastx_uniques)
+    {
+      if ((!opt_uc) && (!opt_fastaout) && (!opt_fastqout) && (!opt_tabbedout))
+        fatal("Output file for dereplication with fastx_uniques must be specified with --fastaout, --fastqout, --tabbedout, or --uc");
+    }
+  else
+    {
+      if ((!opt_output) && (!opt_uc))
+        fatal("Output file for dereplication must be specified with --output or --uc");
+    }
+
+  if (opt_fastx_uniques)
+    {
+      if (opt_fastaout)
+        {
+          fp_fastaout = fopen_output(opt_fastaout);
+          if (!fp_fastaout)
+            {
+              fatal("Unable to open FASTA output file for writing");
+            }
+        }
+
+      if (opt_fastqout)
+        {
+          fp_fastqout = fopen_output(opt_fastqout);
+          if (!fp_fastqout)
+            {
+              fatal("Unable to open FASTQ output file for writing");
+            }
+        }
+
+      if (opt_tabbedout)
+        {
+          fp_tabbedout = fopen_output(opt_tabbedout);
+          if (!fp_tabbedout)
+            {
+              fatal("Unable to open tab delimited output file for writing");
+            }
+        }
+    }
+  else
+    {
+      if (opt_output)
+        {
+          fp_fastaout = fopen_output(opt_output);
+          if (!fp_fastaout)
+            {
+              fatal("Unable to open FASTA output file for writing");
+            }
+        }
     }
 
   if (opt_uc)
     {
       fp_uc = fopen_output(opt_uc);
       if (!fp_uc)
-        fatal("Unable to open output (uc) file for writing");
+        {
+          fatal("Unable to open output (uc) file for writing");
+        }
     }
 
-  fastx_handle h = fastx_open(input_filename);
-
-  show_rusage();
-
-  if (!h)
-    fatal("Unrecognized input file type (not proper FASTA or FASTQ format)");
-
   uint64_t filesize = fastx_get_size(h);
 
 
@@ -246,20 +380,23 @@ void derep(char * input_filename, bool use_header)
 
   uint64_t hashtablesize = 2 * alloc_clusters;
   uint64_t hash_mask = hashtablesize - 1;
-  struct bucket * hashtable =
+  auto * hashtable =
     (struct bucket *) xmalloc(sizeof(bucket) * hashtablesize);
   memset(hashtable, 0, sizeof(bucket) * hashtablesize);
 
   show_rusage();
 
-  unsigned int * nextseqtab = 0;
-  const unsigned int terminal = (unsigned int)(-1);
-  char ** headertab = 0;
-  char * match_strand = 0;
+  unsigned int * nextseqtab = nullptr;
+  const auto terminal = (unsigned int)(-1);
+  char ** headertab = nullptr;
+  char * match_strand = nullptr;
 
-  if (opt_uc)
+  bool extra_info = opt_uc || opt_tabbedout;
+
+  if (extra_info)
     {
-      /* If the uc option is in effect we need to keep some extra info.
+      /* If the uc or tabbedout option is in effect,
+         we need to keep some extra info.
          Allocate and init memory for this. */
 
       /* Links to other sequences in cluster */
@@ -281,9 +418,11 @@ void derep(char * input_filename, bool use_header)
   char * seq_up = (char*) xmalloc(alloc_seqlen + 1);
   char * rc_seq_up = (char*) xmalloc(alloc_seqlen + 1);
 
-  char * prompt = 0;
+  char * prompt = nullptr;
   if (xsprintf(& prompt, "Dereplicating file %s", input_filename) == -1)
-    fatal("Out of memory");
+    {
+      fatal("Out of memory");
+    }
 
   progress_init(prompt, filesize);
 
@@ -317,9 +456,13 @@ void derep(char * input_filename, bool use_header)
 
       nucleotidecount += seqlen;
       if (seqlen > longest)
-        longest = seqlen;
+        {
+          longest = seqlen;
+        }
       if (seqlen < shortest)
-        shortest = seqlen;
+        {
+          shortest = seqlen;
+        }
 
       /* check allocations */
 
@@ -332,7 +475,7 @@ void derep(char * input_filename, bool use_header)
           show_rusage();
         }
 
-      if (opt_uc && (sequencecount + 1 > alloc_seqs))
+      if (extra_info && (sequencecount + 1 > alloc_seqs))
         {
           uint64_t new_alloc_seqs = 2 * alloc_seqs;
 
@@ -371,13 +514,16 @@ void derep(char * input_filename, bool use_header)
       char * seq = fastx_get_sequence(h);
       char * header = fastx_get_header(h);
       int64_t headerlen = fastx_get_header_length(h);
+      char * qual = fastx_get_quality(h); // nullptr if FASTA
 
       /* normalize sequence: uppercase and replace U by T  */
       string_normalize(seq_up, seq, seqlen);
 
       /* reverse complement if necessary */
       if (opt_strand > 1)
-        reverse_complement(rc_seq_up, seq_up, seqlen);
+        {
+          reverse_complement(rc_seq_up, seq_up, seqlen);
+        }
 
       /*
         Find free bucket or bucket for identical sequence.
@@ -389,9 +535,13 @@ void derep(char * input_filename, bool use_header)
 
       uint64_t hash_header;
       if (use_header)
-        hash_header = HASH(header, headerlen);
+        {
+          hash_header = HASH(header, headerlen);
+        }
       else
-        hash_header = 0;
+        {
+          hash_header = 0;
+        }
 
       uint64_t hash = HASH(seq_up, seqlen) ^ hash_header;
       uint64_t j = hash & hash_mask;
@@ -430,8 +580,10 @@ void derep(char * input_filename, bool use_header)
             {
               bp = rc_bp;
               j = k;
-              if (opt_uc)
-                match_strand[sequencecount] = 1;
+              if (extra_info)
+                {
+                  match_strand[sequencecount] = 1;
+                }
             }
         }
 
@@ -442,15 +594,75 @@ void derep(char * input_filename, bool use_header)
       if (bp->size)
         {
           /* at least one identical sequence already */
-          bp->size += ab;
-
-          if (opt_uc)
+          if (extra_info)
             {
               unsigned int last = bp->seqno_last;
               nextseqtab[last] = sequencecount;
               bp->seqno_last = sequencecount;
               headertab[sequencecount] = xstrdup(header);
             }
+
+          int64_t s1 = bp->size;
+          int64_t s2 = ab;
+          int64_t s3 = s1 + s2;
+
+          if (opt_fastqout)
+            {
+              /* update quality scores */
+              for (int i = 0; i < seqlen; i++)
+                {
+                  int q1 = bp->qual[i];
+                  int q2 = qual[i];
+                  double p1 = convert_q_to_p(q1);
+                  double p2 = convert_q_to_p(q2);
+                  double p3;
+
+                  /* how to compute the new quality score? */
+
+                  if (opt_fastq_qout_max)
+                    {
+                      // fastq_qout_max
+                      /* min error prob, highest quality */
+                      p3 = MIN(p1, p2);
+                    }
+                  else
+                    {
+                      // fastq_qout_avg
+                      /* average, as in USEARCH */
+                      p3 = (p1 * s1 + p2 * s2) / s3;
+                    }
+
+                  // fastq_qout_min
+                  /* max error prob, lowest quality */
+                  // p3 = MAX(p1, p2);
+
+                  // fastq_qout_first
+                  /* keep first */
+                  // p3 = p1;
+
+                  // fastq_qout_last
+                  /* keep last */
+                  // p3 = p2;
+
+                  // fastq_qout_ef
+                  /* Compute as multiple independent observations
+                     Edgar & Flyvbjerg (2015)
+                     But what about s1 and s2? */
+                  // p3 = p1 * p2 / 3.0 / (1.0 - p1 - p2 + (4.0 * p1 * p2 / 3.0));
+
+                  /* always worst quality possible, certain error */
+                  // p3 = 1.0;
+
+                  // always best quality possible, perfect, no errors */
+                  // p3 = 0.0;
+
+                  int q3 = convert_p_to_q(p3);
+                  bp->qual[i] = q3;
+                }
+            }
+
+          bp->size = s3;
+          bp->count++;
         }
       else
         {
@@ -461,11 +673,18 @@ void derep(char * input_filename, bool use_header)
           bp->seqno_last = sequencecount;
           bp->seq = xstrdup(seq);
           bp->header = xstrdup(header);
+          bp->count = 1;
+          if (qual)
+            bp->qual = xstrdup(qual);
+          else
+            bp->qual = nullptr;
           clusters++;
         }
 
       if (bp->size > maxsize)
-        maxsize = bp->size;
+        {
+          maxsize = bp->size;
+        }
 
       sequencecount++;
 
@@ -480,37 +699,45 @@ void derep(char * input_filename, bool use_header)
   if (!opt_quiet)
     {
       if (sequencecount > 0)
-        fprintf(stderr,
-                "%'" PRIu64 " nt in %'" PRIu64 " seqs, min %'" PRIu64
-                ", max %'" PRIu64 ", avg %'.0f\n",
-                nucleotidecount,
-                sequencecount,
-                shortest,
-                longest,
-                nucleotidecount * 1.0 / sequencecount);
+        {
+          fprintf(stderr,
+                  "%'" PRIu64 " nt in %'" PRIu64 " seqs, min %'" PRIu64
+                  ", max %'" PRIu64 ", avg %'.0f\n",
+                  nucleotidecount,
+                  sequencecount,
+                  shortest,
+                  longest,
+                  nucleotidecount * 1.0 / sequencecount);
+        }
       else
-        fprintf(stderr,
-                "%'" PRIu64 " nt in %'" PRIu64 " seqs\n",
-                nucleotidecount,
-                sequencecount);
+        {
+          fprintf(stderr,
+                  "%'" PRIu64 " nt in %'" PRIu64 " seqs\n",
+                  nucleotidecount,
+                  sequencecount);
+        }
     }
 
   if (opt_log)
     {
       if (sequencecount > 0)
-        fprintf(fp_log,
-                "%'" PRIu64 " nt in %'" PRIu64 " seqs, min %'" PRIu64
-                ", max %'" PRIu64 ", avg %'.0f\n",
-                nucleotidecount,
-                sequencecount,
-                shortest,
-                longest,
-                nucleotidecount * 1.0 / sequencecount);
+        {
+          fprintf(fp_log,
+                  "%'" PRIu64 " nt in %'" PRIu64 " seqs, min %'" PRIu64
+                  ", max %'" PRIu64 ", avg %'.0f\n",
+                  nucleotidecount,
+                  sequencecount,
+                  shortest,
+                  longest,
+                  nucleotidecount * 1.0 / sequencecount);
+        }
       else
-        fprintf(fp_log,
-                "%'" PRIu64 " nt in %'" PRIu64 " seqs\n",
-                nucleotidecount,
-                sequencecount);
+        {
+          fprintf(fp_log,
+                  "%'" PRIu64 " nt in %'" PRIu64 " seqs\n",
+                  nucleotidecount,
+                  sequencecount);
+        }
     }
 
   if (discarded_short)
@@ -522,11 +749,13 @@ void derep(char * input_filename, bool use_header)
               (discarded_short == 1 ? "sequence" : "sequences"));
 
       if (opt_log)
-        fprintf(fp_log,
-                "minseqlength %" PRId64 ": %" PRId64 " %s discarded.\n\n",
-                opt_minseqlength,
-                discarded_short,
-                (discarded_short == 1 ? "sequence" : "sequences"));
+        {
+          fprintf(fp_log,
+                  "minseqlength %" PRId64 ": %" PRId64 " %s discarded.\n\n",
+                  opt_minseqlength,
+                  discarded_short,
+                  (discarded_short == 1 ? "sequence" : "sequences"));
+        }
     }
 
   if (discarded_long)
@@ -538,11 +767,13 @@ void derep(char * input_filename, bool use_header)
               (discarded_long == 1 ? "sequence" : "sequences"));
 
       if (opt_log)
-        fprintf(fp_log,
-                "maxseqlength %" PRId64 ": %" PRId64 " %s discarded.\n\n",
-                opt_maxseqlength,
-                discarded_long,
-                (discarded_long == 1 ? "sequence" : "sequences"));
+        {
+          fprintf(fp_log,
+                  "maxseqlength %" PRId64 ": %" PRId64 " %s discarded.\n\n",
+                  opt_maxseqlength,
+                  discarded_long,
+                  (discarded_long == 1 ? "sequence" : "sequences"));
+        }
     }
 
   xfree(seq_up);
@@ -559,10 +790,14 @@ void derep(char * input_filename, bool use_header)
   if (clusters > 0)
     {
       if (clusters % 2)
-        median = hashtable[(clusters-1)/2].size;
+        {
+          median = hashtable[(clusters-1)/2].size;
+        }
       else
-        median = (hashtable[(clusters/2)-1].size +
-                  hashtable[clusters/2].size) / 2.0;
+        {
+          median = (hashtable[(clusters/2)-1].size +
+                    hashtable[clusters/2].size) / 2.0;
+        }
     }
 
   average = 1.0 * sumsize / clusters;
@@ -570,26 +805,34 @@ void derep(char * input_filename, bool use_header)
   if (clusters < 1)
     {
       if (!opt_quiet)
-        fprintf(stderr,
-                "0 unique sequences\n");
+        {
+          fprintf(stderr,
+                  "0 unique sequences\n");
+        }
       if (opt_log)
-        fprintf(fp_log,
-                "0 unique sequences\n\n");
+        {
+          fprintf(fp_log,
+                  "0 unique sequences\n\n");
+        }
     }
   else
     {
       if (!opt_quiet)
-        fprintf(stderr,
-                "%" PRId64
-                " unique sequences, avg cluster %.1lf, median %.0f, max %"
-                PRIu64 "\n",
-                clusters, average, median, maxsize);
+        {
+          fprintf(stderr,
+                  "%" PRId64
+                  " unique sequences, avg cluster %.1lf, median %.0f, max %"
+                  PRIu64 "\n",
+                  clusters, average, median, maxsize);
+        }
       if (opt_log)
-        fprintf(fp_log,
-                "%" PRId64
-                " unique sequences, avg cluster %.1lf, median %.0f, max %"
-                PRIu64 "\n\n",
-                clusters, average, median, maxsize);
+        {
+          fprintf(fp_log,
+                  "%" PRId64
+                  " unique sequences, avg cluster %.1lf, median %.0f, max %"
+                  PRIu64 "\n\n",
+                  clusters, average, median, maxsize);
+        }
     }
 
   /* count selected */
@@ -603,7 +846,9 @@ void derep(char * input_filename, bool use_header)
         {
           selected++;
           if (selected == (uint64_t) opt_topn)
-            break;
+            {
+              break;
+            }
         }
     }
 
@@ -611,9 +856,9 @@ void derep(char * input_filename, bool use_header)
 
   /* write output */
 
-  if (opt_output)
+  if (opt_output || opt_fastaout)
     {
-      progress_init("Writing output file", clusters);
+      progress_init("Writing FASTA output file", clusters);
 
       int64_t relabel_count = 0;
       for (uint64_t i=0; i<clusters; i++)
@@ -623,8 +868,8 @@ void derep(char * input_filename, bool use_header)
           if ((size >= opt_minuniquesize) && (size <= opt_maxuniquesize))
             {
               relabel_count++;
-              fasta_print_general(fp_output,
-                                  0,
+              fasta_print_general(fp_fastaout,
+                                  nullptr,
                                   bp->seq,
                                   strlen(bp->seq),
                                   bp->header,
@@ -632,15 +877,50 @@ void derep(char * input_filename, bool use_header)
                                   size,
                                   relabel_count,
                                   -1.0,
-                                  -1, -1, 0, 0.0);
+                                  -1, -1, nullptr, 0.0);
               if (relabel_count == opt_topn)
-                break;
+                {
+                  break;
+                }
             }
           progress_update(i);
         }
 
       progress_done();
-      fclose(fp_output);
+      fclose(fp_fastaout);
+    }
+
+  if (opt_fastqout)
+    {
+      progress_init("Writing FASTQ output file", clusters);
+
+      int64_t relabel_count = 0;
+      for (uint64_t i=0; i<clusters; i++)
+        {
+          struct bucket * bp = hashtable + i;
+          int64_t size = bp->size;
+          if ((size >= opt_minuniquesize) && (size <= opt_maxuniquesize))
+            {
+              relabel_count++;
+              fastq_print_general(fp_fastqout,
+                                  bp->seq,
+                                  strlen(bp->seq),
+                                  bp->header,
+                                  strlen(bp->header),
+                                  bp->qual,
+                                  size,
+                                  relabel_count,
+                                  -1.0);
+              if (relabel_count == opt_topn)
+                {
+                  break;
+                }
+            }
+          progress_update(i);
+        }
+
+      progress_done();
+      fclose(fp_fastqout);
     }
 
   show_rusage();
@@ -660,11 +940,13 @@ void derep(char * input_filename, bool use_header)
           for (unsigned int next = nextseqtab[bp->seqno_first];
                next != terminal;
                next = nextseqtab[next])
-            fprintf(fp_uc,
-                    "H\t%" PRId64 "\t%" PRId64 "\t%.1f\t%s\t0\t0\t*\t%s\t%s\n",
-                    i, len, 100.0,
-                    (match_strand[next] ? "-" : "+"),
-                    headertab[next], hh);
+            {
+              fprintf(fp_uc,
+                      "H\t%" PRId64 "\t%" PRId64 "\t%.1f\t%s\t0\t0\t*\t%s\t%s\n",
+                      i, len, 100.0,
+                      (match_strand[next] ? "-" : "+"),
+                      headertab[next], hh);
+            }
 
           progress_update(i);
         }
@@ -682,23 +964,67 @@ void derep(char * input_filename, bool use_header)
       progress_done();
     }
 
+  if (opt_tabbedout)
+    {
+      progress_init("Writing tab separated file", clusters);
+      for (uint64_t i=0; i<clusters; i++)
+        {
+          struct bucket * bp = hashtable + i;
+          char * hh =  bp->header;
+
+          if (opt_relabel)
+            fprintf(fp_tabbedout,
+                    "%s\t%s%" PRIu64 "\t%" PRIu64 "\t%" PRIu64 "\t%u\t%s\n",
+                    hh, opt_relabel, i + 1, i, (uint64_t) 0, bp->count, hh);
+          else
+            fprintf(fp_tabbedout,
+                    "%s\t%s\t%" PRIu64 "\t%" PRIu64 "\t%u\t%s\n",
+                    hh, hh, i, (uint64_t) 0, bp->count, hh);
+
+          uint64_t j = 1;
+          for (unsigned int next = nextseqtab[bp->seqno_first];
+               next != terminal;
+               next = nextseqtab[next])
+            {
+              if (opt_relabel)
+                fprintf(fp_tabbedout,
+                        "%s\t%s%" PRIu64 "\t%" PRIu64 "\t%" PRIu64 "\t%u\t%s\n",
+                        headertab[next], opt_relabel, i + 1, i, j, bp->count, hh);
+              else
+                fprintf(fp_tabbedout,
+                        "%s\t%s\t%" PRIu64 "\t%" PRIu64 "\t%u\t%s\n",
+                        headertab[next], hh, i, j, bp->count, hh);
+              j++;
+            }
+
+          progress_update(i);
+        }
+      fclose(fp_tabbedout);
+      progress_done();
+    }
+
+
   show_rusage();
 
   if (selected < clusters)
     {
       if (!opt_quiet)
-        fprintf(stderr,
-                "%" PRId64 " uniques written, %"
-                PRId64 " clusters discarded (%.1f%%)\n",
-                selected, clusters - selected,
-                100.0 * (clusters - selected) / clusters);
+        {
+          fprintf(stderr,
+                  "%" PRId64 " uniques written, %"
+                  PRId64 " clusters discarded (%.1f%%)\n",
+                  selected, clusters - selected,
+                  100.0 * (clusters - selected) / clusters);
+        }
 
       if (opt_log)
-        fprintf(fp_log,
-                "%" PRId64 " uniques written, %"
-                PRId64 " clusters discarded (%.1f%%)\n\n",
-                selected, clusters - selected,
-                100.0 * (clusters - selected) / clusters);
+        {
+          fprintf(fp_log,
+                  "%" PRId64 " uniques written, %"
+                  PRId64 " clusters discarded (%.1f%%)\n\n",
+                  selected, clusters - selected,
+                  100.0 * (clusters - selected) / clusters);
+        }
     }
 
   show_rusage();
@@ -712,14 +1038,20 @@ void derep(char * input_filename, bool use_header)
         {
           xfree(bp->seq);
           xfree(bp->header);
+          if (bp->qual)
+            xfree(bp->qual);
         }
     }
 
   if (opt_uc)
     {
       for (uint64_t i=0; i<alloc_seqs; i++)
-        if (headertab[i])
-          xfree(headertab[i]);
+        {
+          if (headertab[i])
+            {
+              xfree(headertab[i]);
+            }
+        }
       xfree(headertab);
       xfree(nextseqtab);
       xfree(match_strand);
@@ -734,21 +1066,30 @@ void derep(char * input_filename, bool use_header)
 
 void derep_prefix()
 {
-  FILE * fp_output = 0;
-  FILE * fp_uc = 0;
+  FILE * fp_output = nullptr;
+  FILE * fp_uc = nullptr;
+
+  if (opt_strand > 1)
+    {
+      fatal("Option '--strand both' not supported with --derep_prefix");
+    }
 
   if (opt_output)
     {
       fp_output = fopen_output(opt_output);
       if (!fp_output)
-        fatal("Unable to open output file for writing");
+        {
+          fatal("Unable to open output file for writing");
+        }
     }
 
   if (opt_uc)
     {
       fp_uc = fopen_output(opt_uc);
       if (!fp_uc)
-        fatal("Unable to open output (uc) file for writing");
+        {
+          fatal("Unable to open output (uc) file for writing");
+        }
     }
 
   db_read(opt_derep_prefix, 0);
@@ -770,7 +1111,7 @@ void derep_prefix()
     }
   int hash_mask = hashtablesize - 1;
 
-  struct bucket * hashtable =
+  auto * hashtable =
     (struct bucket *) xmalloc(sizeof(bucket) * hashtablesize);
 
   memset(hashtable, 0, sizeof(bucket) * hashtablesize);
@@ -783,9 +1124,9 @@ void derep_prefix()
 
   /* alloc and init table of links to other sequences in cluster */
 
-  unsigned int * nextseqtab
+  auto * nextseqtab
     = (unsigned int*) xmalloc(sizeof(unsigned int) * dbsequencecount);
-  const unsigned int terminal = (unsigned int)(-1);
+  const auto terminal = (unsigned int)(-1);
   memset(nextseqtab, -1, sizeof(unsigned int) * dbsequencecount);
 
   char * seq_up = (char*) xmalloc(db_getlongestsequence() + 1);
@@ -794,7 +1135,7 @@ void derep_prefix()
 
   unsigned int len_longest = db_getlongestsequence();
   unsigned int len_shortest = db_getshortestsequence();
-  uint64_t * prefix_hashes = (uint64_t *)
+  auto * prefix_hashes = (uint64_t *)
     xmalloc(sizeof(uint64_t) * (len_longest+1));
 
   progress_init("Dereplicating", dbsequencecount);
@@ -810,22 +1151,22 @@ void derep_prefix()
       sumsize += ab;
 
       /*
-         Look for matching identical or prefix sequences.
+        Look for matching identical or prefix sequences.
 
-         Use a hash function that can quickly be applied iteratively on longer
-         and longer sequences.
+        Use a hash function that can quickly be applied iteratively on longer
+        and longer sequences.
 
-         Hash values are generated for all prefixes and saved.
+        Hash values are generated for all prefixes and saved.
 
-         Should start at exact sequence and then try shorter and shorter
-         sequences.
+        Should start at exact sequence and then try shorter and shorter
+        sequences.
 
-         No need to check shorter sequences than the shortest in the database.
+        No need to check shorter sequences than the shortest in the database.
 
-         Three cases:
-         1) Exact match: Update count, point to next
-         2) Prefix match: Mark old, insert new, update count, point to next
-         3) No match: Insert new entry
+        Three cases:
+        1) Exact match: Update count, point to next
+        2) Prefix match: Mark old, insert new, update count, point to next
+        3) No match: Insert new entry
 
       */
 
@@ -855,7 +1196,9 @@ void derep_prefix()
         {
           bp++;
           if (bp >= hashtable + hashtablesize)
-            bp = hashtable;
+            {
+              bp = hashtable;
+            }
         }
 
       /* at this point, bp points either to (1) a free empty hash bucket, or
@@ -873,7 +1216,9 @@ void derep_prefix()
           bp->seqno_last = i;
 
           if (bp->size > maxsize)
-            maxsize = bp->size;
+            {
+              maxsize = bp->size;
+            }
         }
       else
         {
@@ -895,7 +1240,9 @@ void derep_prefix()
                 {
                   bp++;
                   if (bp >= hashtable + hashtablesize)
-                    bp = hashtable;
+                    {
+                      bp = hashtable;
+                    }
                 }
             }
 
@@ -918,7 +1265,9 @@ void derep_prefix()
               bp->seqno_last = last;
 
               if (bp->size > maxsize)
-                maxsize = bp->size;
+                {
+                  maxsize = bp->size;
+                }
             }
           else
             {
@@ -929,7 +1278,9 @@ void derep_prefix()
               orig_bp->seqno_last = i;
 
               if (ab > maxsize)
-                maxsize = ab;
+                {
+                  maxsize = ab;
+                }
               clusters++;
             }
         }
@@ -951,10 +1302,14 @@ void derep_prefix()
   if (clusters > 0)
     {
       if (clusters % 2)
-        median = hashtable[(clusters-1)/2].size;
+        {
+          median = hashtable[(clusters-1)/2].size;
+        }
       else
-        median = (hashtable[(clusters/2)-1].size +
-                  hashtable[clusters/2].size) / 2.0;
+        {
+          median = (hashtable[(clusters/2)-1].size +
+                    hashtable[clusters/2].size) / 2.0;
+        }
     }
 
   average = 1.0 * sumsize / clusters;
@@ -962,26 +1317,34 @@ void derep_prefix()
   if (clusters < 1)
     {
       if (!opt_quiet)
-        fprintf(stderr,
-                "0 unique sequences\n");
+        {
+          fprintf(stderr,
+                  "0 unique sequences\n");
+        }
       if (opt_log)
-        fprintf(fp_log,
-                "0 unique sequences\n\n");
+        {
+          fprintf(fp_log,
+                  "0 unique sequences\n\n");
+        }
     }
   else
     {
       if (!opt_quiet)
-        fprintf(stderr,
-                "%" PRId64
-                " unique sequences, avg cluster %.1lf, median %.0f, max %"
-                PRIu64 "\n",
-                clusters, average, median, maxsize);
+        {
+          fprintf(stderr,
+                  "%" PRId64
+                  " unique sequences, avg cluster %.1lf, median %.0f, max %"
+                  PRIu64 "\n",
+                  clusters, average, median, maxsize);
+        }
       if (opt_log)
-        fprintf(fp_log,
-                "%" PRId64
-                " unique sequences, avg cluster %.1lf, median %.0f, max %"
-                PRIu64 "\n\n",
-                clusters, average, median, maxsize);
+        {
+          fprintf(fp_log,
+                  "%" PRId64
+                  " unique sequences, avg cluster %.1lf, median %.0f, max %"
+                  PRIu64 "\n\n",
+                  clusters, average, median, maxsize);
+        }
     }
 
   show_rusage();
@@ -997,7 +1360,9 @@ void derep_prefix()
         {
           selected++;
           if (selected == opt_topn)
-            break;
+            {
+              break;
+            }
         }
     }
 
@@ -1017,7 +1382,7 @@ void derep_prefix()
             {
               relabel_count++;
               fasta_print_general(fp_output,
-                                  0,
+                                  nullptr,
                                   db_getsequence(bp->seqno_first),
                                   db_getsequencelen(bp->seqno_first),
                                   db_getheader(bp->seqno_first),
@@ -1025,9 +1390,11 @@ void derep_prefix()
                                   size,
                                   relabel_count,
                                   -1.0,
-                                  -1, -1, 0, 0.0);
+                                  -1, -1, nullptr, 0.0);
               if (relabel_count == opt_topn)
-                break;
+                {
+                  break;
+                }
             }
           progress_update(i);
         }
@@ -1053,9 +1420,11 @@ void derep_prefix()
           for (unsigned int next = nextseqtab[bp->seqno_first];
                next != terminal;
                next = nextseqtab[next])
-            fprintf(fp_uc,
-                    "H\t%" PRId64 "\t%" PRIu64 "\t%.1f\t+\t0\t0\t*\t%s\t%s\n",
-                    i, db_getsequencelen(next), 100.0, db_getheader(next), h);
+            {
+              fprintf(fp_uc,
+                      "H\t%" PRId64 "\t%" PRIu64 "\t%.1f\t+\t0\t0\t*\t%s\t%s\n",
+                      i, db_getsequencelen(next), 100.0, db_getheader(next), h);
+            }
 
           progress_update(i);
         }
@@ -1078,31 +1447,25 @@ void derep_prefix()
   if (selected < clusters)
     {
       if (!opt_quiet)
-        fprintf(stderr,
-                "%" PRId64 " uniques written, %" PRId64
-                " clusters discarded (%.1f%%)\n",
-                selected, clusters - selected,
-                100.0 * (clusters - selected) / clusters);
+        {
+          fprintf(stderr,
+                  "%" PRId64 " uniques written, %" PRId64
+                  " clusters discarded (%.1f%%)\n",
+                  selected, clusters - selected,
+                  100.0 * (clusters - selected) / clusters);
+        }
 
       if (opt_log)
-        fprintf(fp_log,
-                "%" PRId64 " uniques written, %" PRId64
-                " clusters discarded (%.1f%%)\n\n",
-                selected, clusters - selected,
-                100.0 * (clusters - selected) / clusters);
+        {
+          fprintf(fp_log,
+                  "%" PRId64 " uniques written, %" PRId64
+                  " clusters discarded (%.1f%%)\n\n",
+                  selected, clusters - selected,
+                  100.0 * (clusters - selected) / clusters);
+        }
     }
 
   xfree(nextseqtab);
   xfree(hashtable);
   db_free();
 }
-
-void derep_fulllength()
-{
-  derep(opt_derep_fulllength, false);
-}
-
-void derep_id()
-{
-  derep(opt_derep_id, true);
-}
