@@ -64,53 +64,69 @@
 
 FILE * join_fileopenw(char * filename)
 {
-  FILE * fp = 0;
+  FILE * fp = nullptr;
   fp = fopen_output(filename);
   if (!fp)
-    fatal("Unable to open file for writing (%s)", filename);
+    {
+      fatal("Unable to open file for writing (%s)", filename);
+    }
   return fp;
 }
 
 void fastq_join()
 {
-  FILE * fp_fastqout = 0;
-  FILE * fp_fastaout = 0;
+  FILE * fp_fastqout = nullptr;
+  FILE * fp_fastaout = nullptr;
 
-  fastx_handle fastq_fwd = 0;
-  fastx_handle fastq_rev = 0;
+  fastx_handle fastq_fwd = nullptr;
+  fastx_handle fastq_rev = nullptr;
 
   uint64_t total = 0;
 
   /* check input and options */
 
   if (!opt_reverse)
-    fatal("No reverse reads file specified with --reverse");
+    {
+      fatal("No reverse reads file specified with --reverse");
+    }
 
   if ((!opt_fastqout) && (!opt_fastaout))
-    fatal("No output files specified");
+    {
+      fatal("No output files specified");
+    }
 
-  char * padgap = 0;
-  char * padgapq = 0;
+  char * padgap = nullptr;
+  char * padgapq = nullptr;
 
   if (opt_join_padgap)
-    padgap = xstrdup(opt_join_padgap);
+    {
+      padgap = xstrdup(opt_join_padgap);
+    }
   else
-    padgap = xstrdup("NNNNNNNN");
+    {
+      padgap = xstrdup("NNNNNNNN");
+    }
 
   uint64_t padlen = strlen(padgap);
 
   if (opt_join_padgapq)
-    padgapq = xstrdup(opt_join_padgapq);
+    {
+      padgapq = xstrdup(opt_join_padgapq);
+    }
   else
     {
       padgapq = (char *) xmalloc(padlen + 1);
       for(uint64_t i = 0; i < padlen; i++)
-        padgapq[i] = 'I';
+        {
+          padgapq[i] = 'I';
+        }
       padgapq[padlen] = 0;
     }
 
   if (padlen != strlen(padgapq))
-    fatal("Strings given by --join_padgap and --join_padgapq differ in length");
+    {
+      fatal("Strings given by --join_padgap and --join_padgapq differ in length");
+    }
 
   /* open input files */
 
@@ -120,9 +136,13 @@ void fastq_join()
   /* open output files */
 
   if (opt_fastqout)
-    fp_fastqout = join_fileopenw(opt_fastqout);
+    {
+      fp_fastqout = join_fileopenw(opt_fastqout);
+    }
   if (opt_fastaout)
-    fp_fastaout = join_fileopenw(opt_fastaout);
+    {
+      fp_fastaout = join_fileopenw(opt_fastaout);
+    }
 
   /* main */
 
@@ -135,13 +155,15 @@ void fastq_join()
 
   uint64_t alloc = 0;
   uint64_t len = 0;
-  char * seq = 0;
-  char * qual = 0;
+  char * seq = nullptr;
+  char * qual = nullptr;
 
-  while(fastq_next(fastq_fwd, 0, chrmap_no_change))
+  while(fastq_next(fastq_fwd, false, chrmap_no_change))
     {
-      if (! fastq_next(fastq_rev, 0, chrmap_no_change))
-        fatal("More forward reads than reverse reads");
+      if (! fastq_next(fastq_rev, false, chrmap_no_change))
+        {
+          fatal("More forward reads than reverse reads");
+        }
 
       uint64_t fwd_seq_length = fastq_get_sequence_length(fastq_fwd);
       uint64_t rev_seq_length = fastq_get_sequence_length(fastq_rev);
@@ -199,7 +221,7 @@ void fastq_join()
       if (opt_fastaout)
         {
           fasta_print_general(fp_fastaout,
-                              0,
+                              nullptr,
                               seq,
                               len,
                               fastq_get_header(fastq_fwd),
@@ -209,7 +231,7 @@ void fastq_join()
                               -1.0,
                               -1,
                               -1,
-                              0,
+                              nullptr,
                               0);
         }
 
@@ -219,8 +241,10 @@ void fastq_join()
 
   progress_done();
 
-  if (fastq_next(fastq_rev, 0, chrmap_no_change))
-    fatal("More reverse reads than forward reads");
+  if (fastq_next(fastq_rev, false, chrmap_no_change))
+    {
+      fatal("More reverse reads than forward reads");
+    }
 
   fprintf(stderr,
           "%" PRIu64 " pairs joined\n",
@@ -229,17 +253,27 @@ void fastq_join()
   /* clean up */
 
   if (opt_fastaout)
-    fclose(fp_fastaout);
+    {
+      fclose(fp_fastaout);
+    }
   if (opt_fastqout)
-    fclose(fp_fastqout);
+    {
+      fclose(fp_fastqout);
+    }
 
   fastq_close(fastq_rev);
-  fastq_rev = 0;
+  fastq_rev = nullptr;
   fastq_close(fastq_fwd);
-  fastq_fwd = 0;
+  fastq_fwd = nullptr;
 
-  xfree(seq);
-  xfree(qual);
+  if (seq)
+    {
+      xfree(seq);
+    }
+  if (qual)
+    {
+      xfree(qual);
+    }
   xfree(padgap);
   xfree(padgapq);
 }
