@@ -77,6 +77,7 @@ struct fastx_s
 {
   bool is_pipe;
   bool is_fastq;
+  bool is_empty;
 
   FILE * fp;
 
@@ -114,6 +115,7 @@ typedef struct fastx_s * fastx_handle;
 /* fastx input */
 
 bool fastx_is_fastq(fastx_handle h);
+bool fastx_is_empty(fastx_handle h);
 void fastx_filter_header(fastx_handle h, bool truncateatspace);
 fastx_handle fastx_open(const char * filename);
 void fastx_close(fastx_handle h);
