@@ -71,7 +71,9 @@ int wo(int len, const char *s, int *beg, int *end)
 {
   int l1 = len - dust_word + 1 - 5; /* smallest possible region is 8 */
   if (l1 < 0)
-    return 0;
+    {
+      return 0;
+    }
 
   int bestv = 0;
   int besti = 0;
@@ -131,7 +133,9 @@ void dust(char * m, int len)
     {
       /* convert sequence to upper case unless hardmask in effect */
       for(int i=0; i < len; i++)
-        m[i] = toupper(m[i]);
+        {
+          m[i] = toupper(m[i]);
+        }
       m[len] = 0;
     }
 
@@ -143,14 +147,24 @@ void dust(char * m, int len)
       if (v > dust_level)
         {
           if (opt_hardmask)
-            for(int j=a+i; j<=b+i; j++)
-              m[j] = 'N';
+            {
+              for(int j=a+i; j<=b+i; j++)
+                {
+                  m[j] = 'N';
+                }
+            }
           else
-            for(int j=a+i; j<=b+i; j++)
-              m[j] = s[j] | 0x20;
+            {
+              for(int j=a+i; j<=b+i; j++)
+                {
+                  m[j] = s[j] | 0x20;
+                }
+            }
 
           if (b < dust_window2)
-            i += dust_window2 - b;
+            {
+              i += dust_window2 - b;
+            }
         }
     }
 
@@ -165,7 +179,7 @@ static int seqcount = 0;
 
 void * dust_all_worker(void * vp)
 {
-  while(1)
+  while(true)
     {
       xpthread_mutex_lock(&mutex);
       int seqno = nextseq;
@@ -182,7 +196,7 @@ void * dust_all_worker(void * vp)
           break;
         }
     }
-  return 0;
+  return nullptr;
 }
 
 void dust_all()
@@ -191,7 +205,7 @@ void dust_all()
   seqcount = db_getsequencecount();
   progress_init("Masking", seqcount);
 
-  xpthread_mutex_init(&mutex, NULL);
+  xpthread_mutex_init(&mutex, nullptr);
 
   xpthread_attr_init(&attr);
   xpthread_attr_setdetachstate(&attr, PTHREAD_CREATE_JOINABLE);
@@ -199,10 +213,14 @@ void dust_all()
   pthread = (pthread_t *) xmalloc(opt_threads * sizeof(pthread_t));
 
   for(int t=0; t<opt_threads; t++)
-    xpthread_create(pthread+t, &attr, dust_all_worker, (void*)(int64_t)t);
+    {
+      xpthread_create(pthread+t, &attr, dust_all_worker, (void*)(int64_t)t);
+    }
 
   for(int t=0; t<opt_threads; t++)
-    xpthread_join(pthread[t], NULL);
+    {
+      xpthread_join(pthread[t], nullptr);
+    }
 
   xfree(pthread);
 
@@ -218,21 +236,32 @@ void hardmask(char * seq, int len)
   /* convert all lower case letters in seq to N */
 
   for(int j=0; j<len; j++)
-    if (seq[j] & 0x20)
-      seq[j] = 'N';
+    {
+      if (seq[j] & 0x20)
+        {
+          seq[j] = 'N';
+        }
+    }
 }
 
 void hardmask_all()
 {
   for(uint64_t i=0; i<db_getsequencecount(); i++)
-    hardmask(db_getsequence(i), db_getsequencelen(i));
+    {
+      hardmask(db_getsequence(i), db_getsequencelen(i));
+    }
 }
 
 void maskfasta()
 {
+  if (!opt_output)
+    fatal("Output file for masking must be specified with --output");
+
   FILE * fp_output = fopen_output(opt_output);
   if (!fp_output)
-    fatal("Unable to open mask output file for writing");
+    {
+      fatal("Unable to open mask output file for writing");
+    }
 
   db_read(opt_maskfasta, 0);
   show_rusage();
@@ -240,9 +269,13 @@ void maskfasta()
   seqcount = db_getsequencecount();
 
   if (opt_qmask == MASK_DUST)
-    dust_all();
+    {
+      dust_all();
+    }
   else if ((opt_qmask == MASK_SOFT) && (opt_hardmask))
-    hardmask_all();
+    {
+      hardmask_all();
+    }
   show_rusage();
 
   progress_init("Writing output", seqcount);
@@ -260,35 +293,48 @@ void maskfasta()
 
 void fastx_mask()
 {
-  FILE * fp_fastaout = 0;
-  FILE * fp_fastqout = 0;
+  FILE * fp_fastaout = nullptr;
+  FILE * fp_fastqout = nullptr;
+
+  if ((!opt_fastaout) && (!opt_fastqout))
+    fatal("Specify output files for masking with --fastaout and/or --fastqout");
 
   if (opt_fastaout)
     {
       fp_fastaout = fopen_output(opt_fastaout);
       if (!fp_fastaout)
-        fatal("Unable to open mask output FASTA file for writing");
+        {
+          fatal("Unable to open mask output FASTA file for writing");
+        }
     }
 
   if (opt_fastqout)
     {
       fp_fastqout = fopen_output(opt_fastqout);
       if (!fp_fastqout)
-        fatal("Unable to open mask output FASTQ file for writing");
+        {
+          fatal("Unable to open mask output FASTQ file for writing");
+        }
     }
 
   db_read(opt_fastx_mask, 0);
   show_rusage();
 
   if (fp_fastqout && ! db_is_fastq())
-    fatal("Cannot write FASTQ output with a FASTA input file, lacking quality scores");
+    {
+      fatal("Cannot write FASTQ output with a FASTA input file, lacking quality scores");
+    }
 
   seqcount = db_getsequencecount();
 
   if (opt_qmask == MASK_DUST)
-    dust_all();
+    {
+      dust_all();
+    }
   else if ((opt_qmask == MASK_SOFT) && (opt_hardmask))
-    hardmask_all();
+    {
+      hardmask_all();
+    }
   show_rusage();
 
   int kept = 0;
@@ -307,47 +353,63 @@ void fastx_mask()
       else if (opt_hardmask)
         {
           for(int j=0; j<len; j++)
-            if (seq[j] != 'N')
-              unmasked++;
+            {
+              if (seq[j] != 'N')
+                {
+                  unmasked++;
+                }
+            }
         }
       else
         {
           for(int j=0; j<len; j++)
-            if (isupper(seq[j]))
-              unmasked++;
+            {
+              if (isupper(seq[j]))
+                {
+                  unmasked++;
+                }
+            }
         }
       double unmasked_pct = 100.0 * unmasked / len;
 
       if (unmasked_pct < opt_min_unmasked_pct)
-        discarded_less++;
+        {
+          discarded_less++;
+        }
       else if (unmasked_pct >  opt_max_unmasked_pct)
-        discarded_more++;
+        {
+          discarded_more++;
+        }
       else
         {
           kept++;
 
           if (opt_fastaout)
-            fasta_print_general(fp_fastaout,
-                                0,
-                                seq,
-                                len,
-                                db_getheader(i),
-                                db_getheaderlen(i),
-                                db_getabundance(i),
-                                kept,
-                                -1.0,
-                                -1, -1, 0, 0.0);
+            {
+              fasta_print_general(fp_fastaout,
+                                  nullptr,
+                                  seq,
+                                  len,
+                                  db_getheader(i),
+                                  db_getheaderlen(i),
+                                  db_getabundance(i),
+                                  kept,
+                                  -1.0,
+                                  -1, -1, nullptr, 0.0);
+            }
 
           if (opt_fastqout)
-            fastq_print_general(fp_fastqout,
-                                seq,
-                                len,
-                                db_getheader(i),
-                                db_getheaderlen(i),
-                                db_getquality(i),
-                                db_getabundance(i),
-                                kept,
-                                -1.0);
+            {
+              fastq_print_general(fp_fastqout,
+                                  seq,
+                                  len,
+                                  db_getheader(i),
+                                  db_getheaderlen(i),
+                                  db_getquality(i),
+                                  db_getabundance(i),
+                                  kept,
+                                  -1.0);
+            }
         }
 
       progress_update(i);
@@ -357,18 +419,26 @@ void fastx_mask()
   if (!opt_quiet)
     {
       if (opt_min_unmasked_pct > 0.0)
-        fprintf(stderr, "%d sequences with less than %.1lf%% unmasked residues discarded\n", discarded_less, opt_min_unmasked_pct);
+        {
+          fprintf(stderr, "%d sequences with less than %.1lf%% unmasked residues discarded\n", discarded_less, opt_min_unmasked_pct);
+        }
       if (opt_max_unmasked_pct < 100.0)
-        fprintf(stderr, "%d sequences with more than %.1lf%% unmasked residues discarded\n", discarded_more, opt_max_unmasked_pct);
+        {
+          fprintf(stderr, "%d sequences with more than %.1lf%% unmasked residues discarded\n", discarded_more, opt_max_unmasked_pct);
+        }
       fprintf(stderr, "%d sequences kept\n", kept);
     }
 
   if (opt_log)
     {
       if (opt_min_unmasked_pct > 0.0)
-        fprintf(fp_log, "%d sequences with less than %.1lf%% unmasked residues discarded\n", discarded_less, opt_min_unmasked_pct);
+        {
+          fprintf(fp_log, "%d sequences with less than %.1lf%% unmasked residues discarded\n", discarded_less, opt_min_unmasked_pct);
+        }
       if (opt_max_unmasked_pct < 100.0)
-        fprintf(fp_log, "%d sequences with more than %.1lf%% unmasked residues discarded\n", discarded_more, opt_max_unmasked_pct);
+        {
+          fprintf(fp_log, "%d sequences with more than %.1lf%% unmasked residues discarded\n", discarded_more, opt_max_unmasked_pct);
+        }
       fprintf(fp_log, "%d sequences kept\n", kept);
     }
 
@@ -376,7 +446,11 @@ void fastx_mask()
   db_free();
 
   if (fp_fastaout)
-    fclose(fp_fastaout);
+    {
+      fclose(fp_fastaout);
+    }
   if (fp_fastqout)
-    fclose(fp_fastqout);
+    {
+      fclose(fp_fastqout);
+    }
 }
