@@ -78,56 +78,82 @@ elem_smaller(elem_t * a, elem_t * b)
 {
   /* return 1 if a is smaller than b, 0 if equal or greater */
   if (a->count < b->count)
-    return 1;
+    {
+      return 1;
+    }
   else
     if (a->count > b->count)
-      return 0;
+      {
+        return 0;
+      }
     else
       if (a->length > b->length)
-        return 1;
+        {
+          return 1;
+        }
       else
         if (a->length < b->length)
-          return 0;
+          {
+            return 0;
+          }
         else
           if (a->seqno > b->seqno)
-            return 1;
+            {
+              return 1;
+            }
           else
-            return 0;
+            {
+              return 0;
+            }
 }
 
 int minheap_compare(const void * a, const void * b)
 {
-  elem_t * x = (elem_t*) a;
-  elem_t * y = (elem_t*) b;
+  auto * x = (elem_t*) a;
+  auto * y = (elem_t*) b;
 
   /* return -1 if a is smaller than b, +1 if greater, otherwize 0 */
   /* first: lower count, larger length, lower seqno */
 
   if (x->count < y->count)
-    return -1;
+    {
+      return -1;
+    }
   else
     if (x->count > y->count)
-      return +1;
+      {
+        return +1;
+      }
     else
       if (x->length > y->length)
-        return -1;
+        {
+          return -1;
+        }
       else
         if (x->length < y->length)
-          return +1;
+          {
+            return +1;
+          }
         else
           if (x->seqno > y->seqno)
-            return -1;
+            {
+              return -1;
+            }
           else
             if (x->seqno < y->seqno)
-              return +1;
+              {
+                return +1;
+              }
             else
-              return 0;
+              {
+                return 0;
+              }
 }
 
 minheap_t *
 minheap_init(int size)
 {
-  minheap_t * m = (minheap_t *) xmalloc(sizeof(minheap_t));
+  auto * m = (minheap_t *) xmalloc(sizeof(minheap_t));
   m->alloc = size;
   m->array = (elem_t *) xmalloc(size * sizeof(elem_t));
   m->count = 0;
@@ -158,7 +184,9 @@ minheap_replaceroot(minheap_t * m, elem_t tmp)
     {
       /* if two children: swap with the one with smallest value */
       if ((c + 1 < m->count) && (elem_smaller(m->array + c + 1, m->array + c)))
-        c++;
+        {
+          c++;
+        }
 
       /* swap parent and child if child has lower value */
       if (elem_smaller(m->array + c, &tmp))
@@ -167,7 +195,9 @@ minheap_replaceroot(minheap_t * m, elem_t tmp)
           swaps++;
         }
       else
-        break;
+        {
+          break;
+        }
 
       /* step down */
       p = c;
@@ -235,7 +265,9 @@ minheap_pop(minheap_t * m)
       return top;
     }
   else
-    return zero;
+    {
+      return zero;
+    }
 }
 
 void
@@ -248,7 +280,9 @@ void
 minheap_dump(minheap_t * m)
 {
   for(int i=0; i < m->count; i++)
-    printf("%s%u", i>0 ? " " : "", m->array[i].count);
+    {
+      printf("%s%u", i>0 ? " " : "", m->array[i].count);
+    }
   printf("\n");
 }
 
@@ -259,9 +293,13 @@ minheap_poplast(minheap_t * m)
   static elem_t zero = {0,0,0};
 
   if (m->count)
-    return m->array[--m->count];
+    {
+      return m->array[--m->count];
+    }
   else
-    return zero;
+    {
+      return zero;
+    }
 }
 
 
