@@ -141,7 +141,9 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
               break;
             case 'D':
               if (run > maxi[pos])
-                maxi[pos] = run;
+                {
+                  maxi[pos] = run;
+                }
               break;
             }
         }
@@ -150,7 +152,9 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
   /* find total alignment length */
   int alnlen = 0;
   for(int i=0; i < centroid_len+1; i++)
-    alnlen += maxi[i];
+    {
+      alnlen += maxi[i];
+    }
   alnlen += centroid_len;
 
   /* allocate memory for profile (for consensus) and aligned seq */
@@ -162,19 +166,27 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
   /* Find longest target sequence on reverse strand and allocate buffer */
   int64_t longest_reversed = 0;
   for(int i=0; i < target_count; i++)
-    if (target_list[i].strand)
-      {
-        int64_t len = db_getsequencelen(target_list[i].seqno);
-        if (len > longest_reversed)
-          longest_reversed = len;
-      }
-  char * rc_buffer = 0;
+    {
+      if (target_list[i].strand)
+        {
+          int64_t len = db_getsequencelen(target_list[i].seqno);
+          if (len > longest_reversed)
+            {
+              longest_reversed = len;
+            }
+        }
+    }
+  char * rc_buffer = nullptr;
   if (longest_reversed > 0)
-    rc_buffer = (char*) xmalloc(longest_reversed + 1);
+    {
+      rc_buffer = (char*) xmalloc(longest_reversed + 1);
+    }
 
   /* blank line before each msa */
   if (fp_msaout)
-    fprintf(fp_msaout, "\n");
+    {
+      fprintf(fp_msaout, "\n");
+    }
 
   for(int j=0; j<target_count; j++)
     {
@@ -200,7 +212,9 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
           for(int x=0; x < centroid_len; x++)
             {
               for(int y=0; y < maxi[qpos]; y++)
-                msa_add('-', target_abundance);
+                {
+                  msa_add('-', target_abundance);
+                }
               msa_add(target_seq[tpos++], target_abundance);
               qpos++;
             }
@@ -222,9 +236,13 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
                   for(int x=0; x < maxi[qpos]; x++)
                     {
                       if (x < run)
-                        msa_add(target_seq[tpos++], target_abundance);
+                        {
+                          msa_add(target_seq[tpos++], target_abundance);
+                        }
                       else
-                        msa_add('-', target_abundance);
+                        {
+                          msa_add('-', target_abundance);
+                        }
                     }
                   inserted = 1;
                 }
@@ -233,13 +251,21 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
                   for(int x=0; x < run; x++)
                     {
                       if (!inserted)
-                        for(int y=0; y < maxi[qpos]; y++)
-                          msa_add('-', target_abundance);
+                        {
+                          for(int y=0; y < maxi[qpos]; y++)
+                            {
+                              msa_add('-', target_abundance);
+                            }
+                        }
 
                       if (op == 'M')
-                        msa_add(target_seq[tpos++], target_abundance);
+                        {
+                          msa_add(target_seq[tpos++], target_abundance);
+                        }
                       else
-                        msa_add('-', target_abundance);
+                        {
+                          msa_add('-', target_abundance);
+                        }
 
                       qpos++;
                       inserted = 0;
@@ -249,26 +275,34 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
         }
 
       if (!inserted)
-        for(int x=0; x < maxi[qpos]; x++)
-          msa_add('-', target_abundance);
+        {
+          for(int x=0; x < maxi[qpos]; x++)
+            {
+              msa_add('-', target_abundance);
+            }
+        }
 
       /* end of sequence string */
       aln[alnpos] = 0;
 
       /* print header & sequence */
       if (fp_msaout)
-        fasta_print_general(fp_msaout,
-                            j ? "" : "*",
-                            aln,
-                            alnlen,
-                            db_getheader(target_seqno),
-                            db_getheaderlen(target_seqno),
-                            db_getabundance(target_seqno),
-                            0, -1.0, -1, -1, 0, 0.0);
+        {
+          fasta_print_general(fp_msaout,
+                              j ? "" : "*",
+                              aln,
+                              alnlen,
+                              db_getheader(target_seqno),
+                              db_getheaderlen(target_seqno),
+                              db_getabundance(target_seqno),
+                              0, -1.0, -1, -1, nullptr, 0.0);
+        }
     }
 
   if (rc_buffer)
-    xfree(rc_buffer);
+    {
+      xfree(rc_buffer);
+    }
 
   /* consensus */
 
@@ -317,7 +351,9 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
               cons[conslen++] = sym;
             }
           else
-            aln[i] = '-';
+            {
+              aln[i] = '-';
+            }
         }
     }
 
@@ -325,7 +361,9 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
   cons[conslen] = 0;
 
   if (fp_msaout)
-    fasta_print(fp_msaout, "consensus", aln, alnlen);
+    {
+      fasta_print(fp_msaout, "consensus", aln, alnlen);
+    }
 
   if (fp_consout)
     {
@@ -340,14 +378,14 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
                           -1.0,
                           target_count,
                           opt_clusterout_id ? cluster : -1,
-                          0, 0.0);
+                          nullptr, 0.0);
     }
 
   if (fp_profile)
     {
       fasta_print_general(fp_profile,
                           "centroid=",
-                          0,
+                          nullptr,
                           0,
                           db_getheader(centroid_seqno),
                           db_getheaderlen(centroid_seqno),
@@ -356,14 +394,16 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
                           -1.0,
                           target_count,
                           opt_clusterout_id ? cluster : -1,
-                          0, 0.0);
+                          nullptr, 0.0);
 
       for (int i=0; i<alnlen; i++)
         {
           fprintf(fp_profile, "%d\t%c", i, aln[i]);
           // A, C, G and T
           for (int c=0; c<4; c++)
-            fprintf(fp_profile, "\t%" PRId64, profile[PROFSIZE*i+c]);
+            {
+              fprintf(fp_profile, "\t%" PRId64, profile[PROFSIZE*i+c]);
+            }
           // Gap symbol
           fprintf(fp_profile, "\t%" PRId64, profile[PROFSIZE*i+5]);
           // Ambiguous nucleotide (Ns and others)
