@@ -115,17 +115,23 @@ void otutable_init()
   if (regcomp(&otutable->regex_sample,
               "(^|;)(sample|barcodelabel)=([^;]*)($|;)",
               REG_EXTENDED))
-    fatal("Compilation of regular expression for sample annotation failed");
+    {
+      fatal("Compilation of regular expression for sample annotation failed");
+    }
 
   if (regcomp(&otutable->regex_otu,
               "(^|;)otu=([^;]*)($|;)",
               REG_EXTENDED))
-    fatal("Compilation of regular expression for otu annotation failed");
+    {
+      fatal("Compilation of regular expression for otu annotation failed");
+    }
 
   if (regcomp(&otutable->regex_tax,
               "(^|;)tax=([^;]*)($|;)",
               REG_EXTENDED))
-    fatal("Compilation of regular expression for taxonomy annotation failed");
+    {
+      fatal("Compilation of regular expression for taxonomy annotation failed");
+    }
 #endif
 }
 
@@ -257,22 +263,25 @@ void otutable_print_otutabout(FILE * fp)
   progress_init("Writing OTU table (classic)", otutable->otu_set.size());
 
   fprintf(fp, "#OTU ID");
-  for (string_set_t::iterator it_sample = otutable->sample_set.begin();
-       it_sample != otutable->sample_set.end();
-       ++it_sample)
-    fprintf(fp, "\t%s", it_sample->c_str());
+  for (const
+         auto & it_sample : otutable->sample_set)
+    {
+      fprintf(fp, "\t%s", it_sample.c_str());
+    }
   if (! otutable->otu_tax_map.empty())
-    fprintf(fp, "\ttaxonomy");
+    {
+      fprintf(fp, "\ttaxonomy");
+    }
   fprintf(fp, "\n");
 
-  string_pair_map_t::iterator it_map = otutable->otu_sample_count.begin();
-  for (string_set_t::iterator it_otu = otutable->otu_set.begin();
+  auto it_map = otutable->otu_sample_count.begin();
+  for (auto it_otu = otutable->otu_set.begin();
        it_otu != otutable->otu_set.end();
        ++it_otu)
     {
       fprintf(fp, "%s", it_otu->c_str());
 
-      for (string_set_t::iterator it_sample = otutable->sample_set.begin();
+      for (auto it_sample = otutable->sample_set.begin();
            it_sample != otutable->sample_set.end();
            ++it_sample)
         {
@@ -289,10 +298,12 @@ void otutable_print_otutabout(FILE * fp)
       if (! otutable->otu_tax_map.empty())
         {
           fprintf(fp, "\t");
-          otu_tax_map_t::iterator it
+          auto it
             = otutable->otu_tax_map.find(*it_otu);
           if (it != otutable->otu_tax_map.end())
-            fprintf(fp, "%s", it->second.c_str());
+            {
+              fprintf(fp, "%s", it->second.c_str());
+            }
         }
       fprintf(fp, "\n");
       progress_update(++progress);
@@ -307,25 +318,24 @@ void otutable_print_mothur_shared_out(FILE * fp)
 
   fprintf(fp, "label\tGroup\tnumOtus");
   int64_t numotus = 0;
-  for (string_set_t::iterator it_otu = otutable->otu_set.begin();
-       it_otu != otutable->otu_set.end();
-       ++it_otu)
+  for (const
+         auto & it_otu : otutable->otu_set)
     {
-      const char * otu_name = it_otu->c_str();
+      const char * otu_name = it_otu.c_str();
       fprintf(fp, "\t%s", otu_name);
       ++numotus;
     }
   fprintf(fp, "\n");
 
-  string_pair_map_t::iterator it_map = otutable->sample_otu_count.begin();
+  auto it_map = otutable->sample_otu_count.begin();
 
-  for (string_set_t::iterator it_sample = otutable->sample_set.begin();
+  for (auto it_sample = otutable->sample_set.begin();
        it_sample != otutable->sample_set.end();
        ++it_sample)
     {
       fprintf(fp, "vsearch\t%s\t%" PRId64, it_sample->c_str(), numotus);
 
-      for (string_set_t::iterator it_otu = otutable->otu_set.begin();
+      for (auto it_otu = otutable->otu_set.begin();
            it_otu != otutable->otu_set.end();
            ++it_otu)
         {
@@ -354,7 +364,7 @@ void otutable_print_biomout(FILE * fp)
   int64_t rows = otutable->otu_set.size();
   int64_t columns = otutable->sample_set.size();
 
-  static time_t time_now = time(0);
+  static time_t time_now = time(nullptr);
   struct tm * tm_now = localtime(& time_now);
   char date[50];
   strftime(date, 50, "%Y-%m-%dT%H:%M:%S", tm_now);
@@ -380,23 +390,29 @@ void otutable_print_biomout(FILE * fp)
   uint64_t otu_no = 0;
 
   fprintf(fp, "\t\"rows\":[");
-  for (string_set_t::iterator it_otu = otutable->otu_set.begin();
+  for (auto it_otu = otutable->otu_set.begin();
        it_otu != otutable->otu_set.end();
        ++it_otu)
     {
       if (it_otu != otutable->otu_set.begin())
-        fprintf(fp, ",");
+        {
+          fprintf(fp, ",");
+        }
       const char * otu_name = it_otu->c_str();
       fprintf(fp, "\n\t\t{\"id\":\"%s\", \"metadata\":", otu_name);
       if (otutable->otu_tax_map.empty())
-        fprintf(fp, "null");
+        {
+          fprintf(fp, "null");
+        }
       else
         {
-          fprintf(fp, "{\"taxonomy\":\"");
-          otu_tax_map_t::iterator it
+          fprintf(fp, R"({"taxonomy":")");
+          auto it
             = otutable->otu_tax_map.find(otu_name);
           if (it != otutable->otu_tax_map.end())
-            fprintf(fp, "%s", it->second.c_str());
+            {
+              fprintf(fp, "%s", it->second.c_str());
+            }
           fprintf(fp, "\"}");
         }
       fprintf(fp, "}");
@@ -409,12 +425,14 @@ void otutable_print_biomout(FILE * fp)
   uint64_t sample_no = 0;
 
   fprintf(fp, "\t\"columns\":[");
-  for (string_set_t::iterator it_sample = otutable->sample_set.begin();
+  for (auto it_sample = otutable->sample_set.begin();
        it_sample != otutable->sample_set.end();
        ++it_sample)
     {
       if (it_sample != otutable->sample_set.begin())
-        fprintf(fp, ",");
+        {
+          fprintf(fp, ",");
+        }
       fprintf(fp, "\n\t\t{\"id\":\"%s\", \"metadata\":null}", it_sample->c_str());
       sample_no_map[*it_sample] = sample_no++;
     }
@@ -423,17 +441,18 @@ void otutable_print_biomout(FILE * fp)
   bool first = true;
   fprintf(fp, "\t\"data\": [");
 
-  for (string_pair_map_t::iterator it_map = otutable->otu_sample_count.begin();
-       it_map != otutable->otu_sample_count.end();
-       ++it_map)
+  for (auto
+         & it_map : otutable->otu_sample_count)
     {
       if (!first)
-        fprintf(fp, ",");
+        {
+          fprintf(fp, ",");
+        }
 
-      otu_no = otu_no_map[it_map->first.first];
-      sample_no = sample_no_map[it_map->first.second];
+      otu_no = otu_no_map[it_map.first.first];
+      sample_no = sample_no_map[it_map.first.second];
 
-      fprintf(fp, "\n\t\t[%" PRIu64 ",%" PRIu64 ",%" PRIu64 "]", otu_no, sample_no, it_map->second);
+      fprintf(fp, "\n\t\t[%" PRIu64 ",%" PRIu64 ",%" PRIu64 "]", otu_no, sample_no, it_map.second);
       first = false;
       progress_update(++progress);
     }
