@@ -76,7 +76,7 @@ void results_show_fastapairs_one(FILE * fp,
                                  hp->nwalignmentlength,
                                  0);
       fasta_print_general(fp,
-                          0,
+                          nullptr,
                           qrow + hp->trim_q_left + hp->trim_t_left,
                           hp->internal_alignmentlength,
                           query_head,
@@ -86,7 +86,7 @@ void results_show_fastapairs_one(FILE * fp,
                           -1.0,
                           -1,
                           -1,
-                          0,
+                          nullptr,
                           0.0);
       xfree(qrow);
 
@@ -95,7 +95,7 @@ void results_show_fastapairs_one(FILE * fp,
                                  hp->nwalignmentlength,
                                  1);
       fasta_print_general(fp,
-                          0,
+                          nullptr,
                           trow + hp->trim_q_left + hp->trim_t_left,
                           hp->internal_alignmentlength,
                           db_getheader(hp->target),
@@ -105,7 +105,7 @@ void results_show_fastapairs_one(FILE * fp,
                           -1.0,
                           -1,
                           -1,
-                          0,
+                          nullptr,
                           0.0);
       xfree(trow);
 
@@ -114,6 +114,65 @@ void results_show_fastapairs_one(FILE * fp,
 }
 
 
+void results_show_qsegout_one(FILE * fp,
+                              struct hit * hp,
+                              char * query_head,
+                              char * qsequence,
+                              int64_t qseqlen,
+                              char * rc)
+{
+  if (hp)
+    {
+      char * qseg = (hp->strand ? rc : qsequence) + hp->trim_q_left;
+      int qseglen = qseqlen
+        - hp->trim_q_left - hp->trim_q_right;
+
+      fasta_print_general(fp,
+                          nullptr,
+                          qseg,
+                          qseglen,
+                          query_head,
+                          strlen(query_head),
+                          0,
+                          0,
+                          -1.0,
+                          -1,
+                          -1,
+                          nullptr,
+                          0.0);
+    }
+}
+
+void results_show_tsegout_one(FILE * fp,
+                              struct hit * hp,
+                              char * query_head,
+                              char * qsequence,
+                              int64_t qseqlen,
+                              char * rc)
+{
+  if (hp)
+    {
+      char * tseg = db_getsequence(hp->target) + hp->trim_t_left;
+      int tseglen = db_getsequencelen(hp->target)
+        - hp->trim_t_left - hp->trim_t_right;
+
+      fasta_print_general(fp,
+                          nullptr,
+                          tseg,
+                          tseglen,
+                          db_getheader(hp->target),
+                          db_getheaderlen(hp->target),
+                          0,
+                          0,
+                          -1.0,
+                          -1,
+                          -1,
+                          nullptr,
+                          0.0);
+    }
+}
+
+
 void results_show_blast6out_one(FILE * fp,
                                 struct hit * hp,
                                 char * query_head,
@@ -123,23 +182,23 @@ void results_show_blast6out_one(FILE * fp,
 {
 
   /*
-     http://www.drive5.com/usearch/manual/blast6out.html
+    http://www.drive5.com/usearch/manual/blast6out.html
 
-     query label
-     target label
-     percent identity
-     alignment length
-     number of mismatches
-     number of gap opens
-     1-based position of start in query
-     1-based position of end in query
-     1-based position of start in target
-     1-based position of end in target
-     E-value
-     bit score
+    query label
+    target label
+    percent identity
+    alignment length
+    number of mismatches
+    number of gap opens
+    1-based position of start in query
+    1-based position of end in query
+    1-based position of start in target
+    1-based position of end in target
+    E-value
+    bit score
 
-     Note that USEARCH shows 13 fields when there is no hit,
-     but only 12 when there is a hit. Fixed in VSEARCH.
+    Note that USEARCH shows 13 fields when there is no hit,
+    but only 12 when there is a hit. Fixed in VSEARCH.
   */
 
   if (hp)
@@ -176,7 +235,7 @@ void results_show_blast6out_one(FILE * fp,
     }
   else
     {
-        fprintf(fp, "%s\t*\t0.0\t0\t0\t0\t0\t0\t0\t0\t-1\t0\n", query_head);
+      fprintf(fp, "%s\t*\t0.0\t0\t0\t0\t0\t0\t0\t0\t-1\t0\n", query_head);
     }
 }
 
@@ -223,17 +282,29 @@ void results_show_uc_one(FILE * fp,
         }
 
       fprintf(fp,
-              "H\t%d\t%" PRId64 "\t%.1f\t%c\t0\t0\t%s\t%s\t%s\n",
+              "H\t%d\t%" PRId64 "\t%.1f\t%c\t0\t0\t%s\t",
               clusterno,
               qseqlen,
               hp->id,
               hp->strand ? '-' : '+',
-              perfect ? "=" : hp->nwalignment,
-              query_head,
-              db_getheader(hp->target));
+              perfect ? "=" : hp->nwalignment);
+      header_fprint_strip_size_ee(fp,
+                                  query_head,
+                                  strlen(query_head),
+                                  opt_xsize,
+                                  opt_xee);
+      fprintf(fp, "\t");
+      header_fprint_strip_size_ee(fp,
+                                  db_getheader(hp->target),
+                                  db_getheaderlen(hp->target),
+                                  opt_xsize,
+                                  opt_xee);
+      fprintf(fp, "\n");
     }
   else
-    fprintf(fp, "N\t*\t*\t*\t.\t*\t*\t*\t%s\t*\n", query_head);
+    {
+      fprintf(fp, "N\t*\t*\t*\t.\t*\t*\t*\t%s\t*\n", query_head);
+    }
 }
 
 void results_show_userout_one(FILE * fp, struct hit * hp,
@@ -250,13 +321,15 @@ void results_show_userout_one(FILE * fp, struct hit * hp,
   for (int c = 0; c < userfields_requested_count; c++)
     {
       if (c)
-        fprintf(fp, "\t");
+        {
+          fprintf(fp, "\t");
+        }
 
       int field = userfields_requested[c];
 
-      char * tsequence = 0;
+      char * tsequence = nullptr;
       int64_t tseqlen = 0;
-      char * t_head = 0;
+      char * t_head = nullptr;
 
       if (hp)
         {
@@ -338,19 +411,27 @@ void results_show_userout_one(FILE * fp, struct hit * hp,
           break;
         case 22: /* aln */
           if (hp)
-            align_fprint_uncompressed_alignment(fp, hp->nwalignment);
+            {
+              align_fprint_uncompressed_alignment(fp, hp->nwalignment);
+            }
           break;
         case 23: /* caln */
           if (hp)
-            fprintf(fp, "%s", hp->nwalignment);
+            {
+              fprintf(fp, "%s", hp->nwalignment);
+            }
           break;
         case 24: /* qstrand */
           if (hp)
-            fprintf(fp, "%c", hp->strand ? '-' : '+');
+            {
+              fprintf(fp, "%c", hp->strand ? '-' : '+');
+            }
           break;
         case 25: /* tstrand */
           if (hp)
-            fprintf(fp, "%c", '+');
+            {
+              fprintf(fp, "%c", '+');
+            }
           break;
         case 26: /* qrow */
           if (hp)
@@ -433,6 +514,82 @@ void results_show_userout_one(FILE * fp, struct hit * hp,
   fprintf(fp, "\n");
 }
 
+void results_show_lcaout(FILE * fp,
+                         struct hit * hits,
+                         int hitcount,
+                         char * query_head,
+                         char * qsequence,
+                         int64_t qseqlen,
+                         char * rc)
+{
+  /* Output last common ancestor (LCA) of the hits,
+     in a similar way to the Sintax command */
+
+  int first_level_start[tax_levels];
+  int first_level_len[tax_levels];
+  int level_match[tax_levels];
+  char * first_h = nullptr;
+
+  fprintf(fp, "%s\t", query_head);
+
+  if (hitcount > 0)
+    {
+      for (int t = 0; t < hitcount; t++)
+        {
+          int seqno = hits[t].target;
+          if (t == 0)
+            {
+              tax_split(seqno, first_level_start, first_level_len);
+              first_h = db_getheader(seqno);
+              for (int j = 0; j < tax_levels; j++)
+                {
+                  level_match[j] = 1;
+                }
+            }
+          else
+            {
+              int level_start[tax_levels];
+              int level_len[tax_levels];
+              tax_split(seqno, level_start, level_len);
+              char * h = db_getheader(seqno);
+              for (int j = 0; j < tax_levels; j++)
+                {
+                  /* For each taxonomic level */
+                  if ((level_len[j] == first_level_len[j]) &&
+                      (strncmp(first_h + first_level_start[j],
+                               h + level_start[j],
+                               level_len[j]) == 0))
+                    {
+                      level_match[j]++;
+                    }
+                }
+            }
+        }
+
+      bool comma = false;
+      for (int j = 0; j < tax_levels; j++)
+        {
+          if (1.0 * level_match[j] / hitcount < opt_lca_cutoff)
+            {
+              break;
+            }
+
+          if (first_level_len[j] > 0)
+            {
+              fprintf(fp,
+                      "%s%c:%.*s",
+                      (comma ? "," : ""),
+                      tax_letters[j],
+                      first_level_len[j],
+                      first_h + first_level_start[j]);
+              comma = true;
+            }
+        }
+    }
+
+  fprintf(fp, "\n");
+}
+
 void results_show_alnout(FILE * fp,
                          struct hit * hits,
                          int hitcount,
@@ -457,7 +614,9 @@ void results_show_alnout(FILE * fp,
           struct hit * hp = hits + t;
 
           if (opt_top_hits_only && (hp->id < top_hit_id))
-            break;
+            {
+              break;
+            }
 
           fprintf(fp,"%3.0f%% %6" PRIu64 "  %s\n",
                   hp->id,
@@ -470,7 +629,9 @@ void results_show_alnout(FILE * fp,
           struct hit * hp = hits + t;
 
           if (opt_top_hits_only && (hp->id < top_hit_id))
-            break;
+            {
+              break;
+            }
 
           fprintf(fp,"\n");
 
@@ -478,8 +639,8 @@ void results_show_alnout(FILE * fp,
           char * dseq = db_getsequence(hp->target);
           int64_t dseqlen = db_getsequencelen(hp->target);
 
-          int qlenlen = snprintf(0, 0, "%" PRId64, qseqlen);
-          int tlenlen = snprintf(0, 0, "%" PRId64, dseqlen);
+          int qlenlen = snprintf(nullptr, 0, "%" PRId64, qseqlen);
+          int tlenlen = snprintf(nullptr, 0, "%" PRId64, dseqlen);
           int numwidth = MAX(qlenlen, tlenlen);
 
           fprintf(fp," Query %*" PRId64 "nt >%s\n", numwidth,
@@ -563,7 +724,7 @@ void build_sam_strings(char * alignment,
   int tpos = 0;
 
   int matched = 0;
-  bool flag = 0; /* 1: MD string ends with a number */
+  bool flag = false; /* 1: MD string ends with a number */
 
   while(p < e)
     {
@@ -582,18 +743,20 @@ void build_sam_strings(char * alignment,
           for(int i=0; i<run; i++)
             {
               if (nucleotide_equal(queryseq[qpos], targetseq[tpos]))
-                matched++;
+                {
+                  matched++;
+                }
               else
                 {
                   if (!flag)
                     {
                       md->add_d(matched);
                       matched = 0;
-                      flag = 1;
+                      flag = true;
                     }
 
                   md->add_c(targetseq[tpos]);
-                  flag = 0;
+                  flag = false;
                 }
               qpos++;
               tpos++;
@@ -615,13 +778,15 @@ void build_sam_strings(char * alignment,
             {
               md->add_d(matched);
               matched = 0;
-              flag = 1;
+              flag = true;
             }
 
           md->add_c('^');
           for(int i=0; i<run; i++)
-            md->add_c(targetseq[tpos++]);
-          flag = 0;
+            {
+              md->add_c(targetseq[tpos++]);
+            }
+          flag = false;
           break;
         }
     }
@@ -630,7 +795,7 @@ void build_sam_strings(char * alignment,
     {
       md->add_d(matched);
       matched = 0;
-      flag = 1;
+      flag = true;
     }
 }
 
@@ -673,39 +838,39 @@ void results_show_samout(FILE * fp,
                          char * rc)
 {
   /*
-     SAM format output
+    SAM format output
 
-     http://samtools.github.io/hts-specs/SAMv1.pdf
-     http://www.drive5.com/usearch/manual/sam_files.html
-     http://bowtie-bio.sourceforge.net/bowtie2/manual.shtml#sam-output
-     http://davetang.org/muse/2011/01/28/perl-and-sam/
+    http://samtools.github.io/hts-specs/SAMv1.pdf
+    http://www.drive5.com/usearch/manual/sam_files.html
+    http://bowtie-bio.sourceforge.net/bowtie2/manual.shtml#sam-output
+    http://davetang.org/muse/2011/01/28/perl-and-sam/
 
-      1: qname, query template name
-      2: flag, bitwise flag (12 bits)
-         (0x004=unmapped, 0x010=rev strand, 0x100 sec. alignment)
-      3: rname, reference sequence name
-      4: pos, 1-based leftmost mapping position (1)
-      5: mapq, mapping quality (255)
-      6: cigar, cigar string (MID)
-      7: rnext, ref name of next/paired read (*)
-      8: pnest, position of next/paired read (0)
-      9: tlen, obs template length (target length)
-     10: seq, segment of sequence
-     11: qual, ascii of phred based quality+33 (*)
-     12: optional tags (tag:type:value)
+    1: qname, query template name
+    2: flag, bitwise flag (12 bits)
+    (0x004=unmapped, 0x010=rev strand, 0x100 sec. alignment)
+    3: rname, reference sequence name
+    4: pos, 1-based leftmost mapping position (1)
+    5: mapq, mapping quality (255)
+    6: cigar, cigar string (MID)
+    7: rnext, ref name of next/paired read (*)
+    8: pnest, position of next/paired read (0)
+    9: tlen, obs template length (target length)
+    10: seq, segment of sequence
+    11: qual, ascii of phred based quality+33 (*)
+    12: optional tags (tag:type:value)
 
-     Optional tags AS, XN, XM, XO, XG, NM, MD and YT used in usearch8.
+    Optional tags AS, XN, XM, XO, XG, NM, MD and YT used in usearch8.
 
-     Usearch8:
+    Usearch8:
 
-     AS:i:? alignment score (i.e percent identity)
-     XN:i:? next best alignment score (always 0?)
-     XM:i:? number of mismatches
-     XO:i:? number of gap opens (excluding terminal gaps)
-     XG:i:? number of gap extensions (excluding terminal gaps)
-     NM:i:? edit distance (sum of XM and XG)
-     MD:Z:? variant string
-     YT:Z:UU string representing alignment type
+    AS:i:? alignment score (i.e percent identity)
+    XN:i:? next best alignment score (always 0?)
+    XM:i:? number of mismatches
+    XO:i:? number of gap opens (excluding terminal gaps)
+    XG:i:? number of gap extensions (excluding terminal gaps)
+    NM:i:? edit distance (sum of XM and XG)
+    MD:Z:? variant string
+    YT:Z:UU string representing alignment type
 
   */
 
@@ -718,11 +883,13 @@ void results_show_samout(FILE * fp,
           struct hit * hp = hits + t;
 
           if (opt_top_hits_only && (hp->id < top_hit_id))
-            break;
+            {
+              break;
+            }
 
           /*
 
-          */
+           */
 
           xstring cigar;
           xstring md;
