@@ -62,9 +62,14 @@
 
 void shuffle()
 {
+  if (!opt_output)
+    fatal("Output file for shuffling must be specified with --output");
+
   FILE * fp_output = fopen_output(opt_output);
   if (!fp_output)
-    fatal("Unable to open shuffle output file for writing");
+    {
+      fatal("Unable to open shuffle output file for writing");
+    }
 
   db_read(opt_shuffle, 0);
   show_rusage();
@@ -73,7 +78,9 @@ void shuffle()
   int * deck = (int*) xmalloc(dbsequencecount * sizeof(int));
 
   for(int i=0; i<dbsequencecount; i++)
-    deck[i] = i;
+    {
+      deck[i] = i;
+    }
 
   int passed = 0;
   progress_init("Shuffling", dbsequencecount-1);
