@@ -85,8 +85,6 @@ static int seqcount; /* number of database sequences */
 static pthread_attr_t attr;
 static fastx_handle query_fastx_h;
 
-const int tax_levels = 8;
-const char * tax_letters = "dkpcofgs";
 const int subset_size = 32;
 const int bootstrap_count = 100;
 
@@ -97,112 +95,6 @@ static FILE * fp_tabbedout;
 static int queries = 0;
 static int classified = 0;
 
-bool sintax_parse_tax(const char * header,
-                      int header_length,
-                      int * tax_start,
-                      int * tax_end)
-{
-  /*
-    Identify the first occurence of the pattern (^|;)tax=([^;]*)(;|$)
-  */
-
-  if (! header)
-    return false;
-
-  const char * attribute = "tax=";
-
-  int hlen = header_length;
-  int alen = strlen(attribute);
-
-  int i = 0;
-
-  while (i < hlen - alen)
-    {
-      char * r = (char *) strstr(header + i, attribute);
-
-      /* no match */
-      if (r == NULL)
-        break;
-
-      i = r - header;
-
-      /* check for ';' in front */
-      if ((i > 0) && (header[i-1] != ';'))
-        {
-          i += alen + 1;
-          continue;
-        }
-
-      * tax_start = i;
-
-      /* find end (semicolon or end of header) */
-      const char * s = strchr(header+i+alen, ';');
-      if (s == 0)
-        * tax_end = hlen;
-      else
-        * tax_end = s - header;
-
-      return true;
-    }
-  return false;
-}
-
-void sintax_split(int seqno, int * level_start, int * level_len)
-{
-  /* Parse taxonomy string into the following parts
-     d domain
-     k kingdom
-     p phylum
-     c class
-     o order
-     f family
-     g genus
-     s species
-  */
-
-  for (int i = 0; i < tax_levels; i++)
-    {
-      level_start[i] = 0;
-      level_len[i] = 0;
-    }
-
-  int tax_start, tax_end;
-  char * h = db_getheader(seqno);
-  int hlen = db_getheaderlen(seqno);
-  if (sintax_parse_tax(h, hlen, & tax_start, & tax_end))
-    {
-      int t = tax_start + 4;
-
-      while (t < tax_end)
-        {
-          /* Is the next char a recogized tax level letter? */
-          const char * r = strchr(tax_letters, tolower(h[t]));
-          if (r)
-            {
-              int level = r - tax_letters;
-
-              /* Is there a colon after it? */
-              if (h[t + 1] == ':')
-                {
-                  level_start[level] = t + 2;
-
-                  char * z = strchr(h + t + 2, ',');
-                  if (z)
-                    level_len[level] = z - h - t - 2;
-                  else
-                    level_len[level] = tax_end - t - 2;
-                }
-            }
-
-          /* skip past next comma */
-          char * x = strchr(h + t, ',');
-          if (x)
-            t = x - h + 1;
-          else
-            t = tax_end;
-        }
-    }
-}
 
 void sintax_analyse(char * query_head,
                     int strand,
@@ -220,10 +112,13 @@ void sintax_analyse(char * query_head,
     {
       char * best_h = db_getheader(best_seqno);
 
-      sintax_split(best_seqno, best_level_start, best_level_len);
+      tax_split(best_seqno, best_level_start, best_level_len);
 
-      for (int j = 0; j < tax_levels; j++)
-        level_match[j] = 0;
+      for (int & j :
+             level_match)
+        {
+          j = 0;
+        }
 
       for (int i = 0; i < count; i++)
         {
@@ -231,7 +126,7 @@ void sintax_analyse(char * query_head,
 
           int level_start[tax_levels];
           int level_len[tax_levels];
-          sintax_split(all_seqno[i], level_start, level_len);
+          tax_split(all_seqno[i], level_start, level_len);
 
           char * h = db_getheader(all_seqno[i]);
 
@@ -303,9 +198,13 @@ void sintax_analyse(char * query_head,
   else
     {
       if (opt_sintax_cutoff > 0.0)
-        fprintf(fp_tabbedout, "\t\t\t");
+        {
+          fprintf(fp_tabbedout, "\t\t\t");
+        }
       else
-        fprintf(fp_tabbedout, "\t\t");
+        {
+          fprintf(fp_tabbedout, "\t\t");
+        }
     }
 
 #if 0
@@ -319,17 +218,9 @@ void sintax_analyse(char * query_head,
 void sintax_query(int64_t t)
 {
   int all_seqno[2][bootstrap_count];
-  int best_seqno[2];
-  int boot_count[2];
-  unsigned int best_count[2];
-
-  best_count[0] = 0;
-  best_count[1] = 0;
-  best_seqno[0] = 0;
-  best_seqno[1] = 0;
-  boot_count[0] = 0;
-  boot_count[1] = 0;
-
+  int best_seqno[2] = {0, 0};
+  int boot_count[2] = {0, 0};
+  unsigned int best_count[2] = {0, 0};
   int qseqlen = si_plus[t].qseqlen;
   char * query_head = si_plus[t].query_head;
 
@@ -393,19 +284,29 @@ void sintax_query(int64_t t)
   int best_strand;
 
   if (opt_strand == 1)
-    best_strand = 0;
+    {
+      best_strand = 0;
+    }
   else
     {
       if (best_count[0] > best_count[1])
-        best_strand = 0;
+        {
+          best_strand = 0;
+        }
       else if (best_count[1] > best_count[0])
-        best_strand = 1;
+        {
+          best_strand = 1;
+        }
       else
         {
           if (boot_count[0] >= boot_count[1])
-            best_strand = 0;
+            {
+              best_strand = 0;
+            }
           else
-            best_strand = 1;
+            {
+              best_strand = 1;
+            }
         }
     }
 
@@ -421,7 +322,7 @@ void sintax_query(int64_t t)
 
 void sintax_thread_run(int64_t t)
 {
-  while (1)
+  while (true)
     {
       xpthread_mutex_lock(&mutex_input);
 
@@ -506,14 +407,14 @@ void sintax_thread_init(struct searchinfo_s * si)
   si->uh = unique_init();
   si->kmers = (count_t *) xmalloc(seqcount * sizeof(count_t) + 32);
   si->m = minheap_init(tophits);
-  si->hits = 0;
+  si->hits = nullptr;
   si->qsize = 1;
   si->query_head_alloc = 0;
-  si->query_head = 0;
+  si->query_head = nullptr;
   si->seq_alloc = 0;
-  si->qsequence = 0;
-  si->nw = 0;
-  si->s = 0;
+  si->qsequence = nullptr;
+  si->nw = nullptr;
+  si->s = nullptr;
 }
 
 void sintax_thread_exit(struct searchinfo_s * si)
@@ -523,16 +424,20 @@ void sintax_thread_exit(struct searchinfo_s * si)
   minheap_exit(si->m);
   xfree(si->kmers);
   if (si->query_head)
-    xfree(si->query_head);
+    {
+      xfree(si->query_head);
+    }
   if (si->qsequence)
-    xfree(si->qsequence);
+    {
+      xfree(si->qsequence);
+    }
 }
 
 void * sintax_thread_worker(void * vp)
 {
-  int64_t t = (int64_t) vp;
+  auto t = (int64_t) vp;
   sintax_thread_run(t);
-  return 0;
+  return nullptr;
 }
 
 void sintax_thread_worker_run()
@@ -547,7 +452,9 @@ void sintax_thread_worker_run()
     {
       sintax_thread_init(si_plus+t);
       if (si_minus)
-        sintax_thread_init(si_minus+t);
+        {
+          sintax_thread_init(si_minus+t);
+        }
       xpthread_create(pthread+t, &attr,
                       sintax_thread_worker, (void*)(int64_t)t);
     }
@@ -555,10 +462,12 @@ void sintax_thread_worker_run()
   /* finish and clean up worker threads */
   for(int t=0; t<opt_threads; t++)
     {
-      xpthread_join(pthread[t], NULL);
+      xpthread_join(pthread[t], nullptr);
       sintax_thread_exit(si_plus+t);
       if (si_minus)
-        sintax_thread_exit(si_minus+t);
+        {
+          sintax_thread_exit(si_minus+t);
+        }
     }
 
   xpthread_attr_destroy(&attr);
@@ -573,25 +482,35 @@ void sintax()
   /* open output files */
 
   if (! opt_db)
-    fatal("No database file specified with --db");
+    {
+      fatal("No database file specified with --db");
+    }
 
   if (opt_tabbedout)
     {
       fp_tabbedout = fopen_output(opt_tabbedout);
       if (! fp_tabbedout)
-        fatal("Unable to open tabbedout output file for writing");
+        {
+          fatal("Unable to open tabbedout output file for writing");
+        }
     }
   else
-    fatal("No output file specified with --tabbedout");
+    {
+      fatal("No output file specified with --tabbedout");
+    }
 
   /* check if db may be an UDB file */
 
   bool is_udb = udb_detect_isudb(opt_db);
 
   if (is_udb)
-    udb_read(opt_db, 1, 1);
+    {
+      udb_read(opt_db, true, true);
+    }
   else
-    db_read(opt_db, 0);
+    {
+      db_read(opt_db, 0);
+    }
 
   seqcount = db_getsequencecount();
 
@@ -610,16 +529,20 @@ void sintax()
   si_plus = (struct searchinfo_s *) xmalloc(opt_threads *
                                             sizeof(struct searchinfo_s));
   if (opt_strand > 1)
-    si_minus = (struct searchinfo_s *) xmalloc(opt_threads *
-                                               sizeof(struct searchinfo_s));
+    {
+      si_minus = (struct searchinfo_s *) xmalloc(opt_threads *
+                                                 sizeof(struct searchinfo_s));
+    }
   else
-    si_minus = 0;
+    {
+      si_minus = nullptr;
+    }
 
   pthread = (pthread_t *) xmalloc(opt_threads * sizeof(pthread_t));
 
   /* init mutexes for input and output */
-  xpthread_mutex_init(&mutex_input, NULL);
-  xpthread_mutex_init(&mutex_output, NULL);
+  xpthread_mutex_init(&mutex_input, nullptr);
+  xpthread_mutex_init(&mutex_output, nullptr);
 
   /* run */
 
@@ -628,12 +551,24 @@ void sintax()
   progress_done();
 
   if (! opt_quiet)
-    fprintf(stderr, "Classified %d of %d sequences (%.2f%%)\n",
-            classified, queries, 100.0 * classified / queries);
+    {
+      fprintf(stderr, "Classified %d of %d sequences", classified, queries);
+      if (queries > 0)
+        {
+          fprintf(stderr, " (%.2f%%)", 100.0 * classified / queries);
+        }
+      fprintf(stderr, "\n");
+    }
 
   if (opt_log)
-    fprintf(fp_log, "Classified %d of %d sequences (%.2f%%)\n",
-            classified, queries, 100.0 * classified / queries);
+    {
+      fprintf(fp_log, "Classified %d of %d sequences", classified, queries);
+      if (queries > 0)
+        {
+          fprintf(fp_log, " (%.2f%%)", 100.0 * classified / queries);
+        }
+      fprintf(fp_log, "\n");
+    }
 
   /* clean up */
 
@@ -643,7 +578,9 @@ void sintax()
   xfree(pthread);
   xfree(si_plus);
   if (si_minus)
-    xfree(si_minus);
+    {
+      xfree(si_minus);
+    }
 
   fastx_close(query_fastx_h);
   fclose(fp_tabbedout);
