@@ -80,7 +80,9 @@ void progress_init(const char * prompt, uint64_t size)
     {
       fprintf(stderr, "%s", prompt);
       if (progress_show)
-        fprintf(stderr, " %d%%", 0);
+        {
+          fprintf(stderr, " %d%%", 0);
+        }
     }
 }
 
@@ -98,7 +100,9 @@ void progress_update(uint64_t progress)
           progress_next = ((progress_pct + 1) * progress_size + 99) / 100;
         }
       else
-        fprintf(stderr, "  \r%s 0%%", progress_prompt);
+        {
+          fprintf(stderr, "  \r%s 0%%", progress_prompt);
+        }
     }
 }
 
@@ -107,7 +111,9 @@ void progress_done()
   if (! opt_quiet)
     {
       if (progress_show)
-        fprintf(stderr, "  \r%s", progress_prompt);
+        {
+          fprintf(stderr, "  \r%s", progress_prompt);
+        }
       fprintf(stderr, " %d%%\n", 100);
     }
 }
@@ -156,19 +162,25 @@ char * xstrchrnul(char *s, int c)
   char * r = strchr(s, c);
 
   if (r)
-    return r;
+    {
+      return r;
+    }
   else
-    return (char *)s + strlen(s);
+    {
+      return (char *)s + strlen(s);
+    }
 }
 
 int xsprintf(char * * ret, const char * format, ...)
 {
   va_list ap;
   va_start(ap, format);
-  int len = vsnprintf(0, 0, format, ap);
+  int len = vsnprintf(nullptr, 0, format, ap);
   va_end(ap);
   if (len < 0)
-    fatal("Error with vsnprintf in xsprintf");
+    {
+      fatal("Error with vsnprintf in xsprintf");
+    }
   char * p = (char *) xmalloc(len + 1);
   va_start(ap, format);
   len = vsnprintf(p, len + 1, format, ap);
@@ -182,10 +194,13 @@ uint64_t hash_cityhash64(char * s, uint64_t n)
   return CityHash64((const char*)s, n);
 }
 
-int64_t getusec(void)
+int64_t getusec()
 {
   struct timeval tv;
-  if(gettimeofday(&tv,0) != 0) return 0;
+  if (gettimeofday(&tv,nullptr) != 0)
+    {
+      return 0;
+    }
   return tv.tv_sec * 1000000 + tv.tv_usec;
 }
 
@@ -215,7 +230,9 @@ void reverse_complement(char * rc, char * seq, int64_t len)
      (identical to the length of seq + 1. */
 
   for(int64_t i=0; i<len; i++)
-    rc[i] = chrmap_complement[(int)(seq[len-1-i])];
+    {
+      rc[i] = chrmap_complement[(int)(seq[len-1-i])];
+    }
   rc[len] = 0;
 }
 
@@ -239,7 +256,9 @@ int64_t random_int(int64_t n)
   int64_t limit = random_max - (random_max + 1) % n;
   int64_t r = arch_random();
   while (r > limit)
-    r = arch_random();
+    {
+      r = arch_random();
+    }
   return r % n;
 }
 
@@ -255,8 +274,10 @@ uint64_t random_ulong(uint64_t n)
   uint64_t r = ((arch_random() << 48) ^ (arch_random() << 32) ^
                 (arch_random() << 16) ^ (arch_random()));
   while (r > limit)
-    r = ((arch_random() << 48) ^ (arch_random() << 32) ^
-         (arch_random() << 16) ^ (arch_random()));
+    {
+      r = ((arch_random() << 48) ^ (arch_random() << 32) ^
+           (arch_random() << 16) ^ (arch_random()));
+    }
   return r % n;
 }
 
@@ -266,20 +287,26 @@ void string_normalize(char * normalized, char * s, unsigned int len)
   char * p = s;
   char * q = normalized;
   for(unsigned int i=0; i<len; i++)
-    *q++ = chrmap_normalize[(int)(*p++)];
+    {
+      *q++ = chrmap_normalize[(int)(*p++)];
+    }
   *q = 0;
 }
 
 void fprint_hex(FILE * fp, unsigned char * data, int len)
 {
   for(int i=0; i<len; i++)
-    fprintf(fp, "%02x", data[i]);
+    {
+      fprintf(fp, "%02x", data[i]);
+    }
 }
 
 void SHA1(const unsigned char * d, unsigned long n, unsigned char * md)
 {
   if (!md)
-    fatal("Error in computing SHA1 digest");
+    {
+      fatal("Error in computing SHA1 digest");
+    }
   SHA1_CTX c;
   SHA1_Init(&c);
   SHA1_Update(&c, d, n);
@@ -289,7 +316,9 @@ void SHA1(const unsigned char * d, unsigned long n, unsigned char * md)
 void MD5(void * d, unsigned long n, unsigned char * md)
 {
   if (!md)
-    fatal("Error in computing MD5 digest");
+    {
+      fatal("Error in computing MD5 digest");
+    }
   MD5_CTX c;
   MD5_Init(&c);
   MD5_Update(&c, d, n);
@@ -366,12 +395,18 @@ FILE * fopen_input(const char * filename)
     {
       int fd = dup(STDIN_FILENO);
       if (fd < 0)
-        return NULL;
+        {
+          return nullptr;
+        }
       else
-        return fdopen(fd, "rb");
+        {
+          return fdopen(fd, "rb");
+        }
     }
   else
-    return fopen(filename, "rb");
+    {
+      return fopen(filename, "rb");
+    }
 }
 
 FILE * fopen_output(const char * filename)
@@ -381,10 +416,16 @@ FILE * fopen_output(const char * filename)
     {
       int fd = dup(STDOUT_FILENO);
       if (fd < 0)
-        return NULL;
+        {
+          return nullptr;
+        }
       else
-        return fdopen(fd, "w");
+        {
+          return fdopen(fd, "w");
+        }
     }
   else
-    return fopen(filename, "w");
+    {
+      return fopen(filename, "w");
+    }
 }
