@@ -250,11 +250,14 @@
 #include "otutable.h"
 #include "udb.h"
 #include "kmerhash.h"
+#include "tax.h"
 #include "sintax.h"
 #include "fastqjoin.h"
 #include "sffconvert.h"
 #include "getseq.h"
 #include "cut.h"
+#include "orient.h"
+#include "fa2fq.h"
 
 /* options */
 
@@ -269,6 +272,7 @@ extern bool opt_fastq_nostagger;
 extern bool opt_gzip_decompress;
 extern bool opt_label_substr_match;
 extern bool opt_no_progress;
+extern bool opt_fastq_qout_max;
 extern bool opt_quiet;
 extern bool opt_relabel_keep;
 extern bool opt_relabel_md5;
@@ -301,6 +305,7 @@ extern char * opt_derep_fulllength;
 extern char * opt_derep_id;
 extern char * opt_derep_prefix;
 extern char * opt_eetabbedout;
+extern char * opt_fasta2fastq;
 extern char * opt_fastaout;
 extern char * opt_fastaout_discarded;
 extern char * opt_fastaout_discarded_rev;
@@ -329,6 +334,7 @@ extern char * opt_fastx_getsubseq;
 extern char * opt_fastx_mask;
 extern char * opt_fastx_revcomp;
 extern char * opt_fastx_subsample;
+extern char * opt_fastx_uniques;
 extern char * opt_join_padgap;
 extern char * opt_join_padgapq;
 extern char * opt_label;
@@ -337,6 +343,7 @@ extern char * opt_labels;
 extern char * opt_label_word;
 extern char * opt_label_words;
 extern char * opt_label_field;
+extern char * opt_lcaout;
 extern char * opt_log;
 extern char * opt_makeudb_usearch;
 extern char * opt_maskfasta;
@@ -346,14 +353,17 @@ extern char * opt_msaout;
 extern char * opt_nonchimeras;
 extern char * opt_notmatched;
 extern char * opt_notmatchedfq;
+extern char * opt_orient;
 extern char * opt_otutabout;
 extern char * opt_output;
 extern char * opt_pattern;
 extern char * opt_profile;
+extern char * opt_qsegout;
 extern char * opt_relabel;
 extern char * opt_rereplicate;
 extern char * opt_reverse;
 extern char * opt_samout;
+extern char * opt_sample;
 extern char * opt_search_exact;
 extern char * opt_sff_convert;
 extern char * opt_shuffle;
@@ -361,6 +371,7 @@ extern char * opt_sintax;
 extern char * opt_sortbylength;
 extern char * opt_sortbysize;
 extern char * opt_tabbedout;
+extern char * opt_tsegout;
 extern char * opt_uc;
 extern char * opt_uchime2_denovo;
 extern char * opt_uchime3_denovo;
@@ -381,6 +392,7 @@ extern double opt_fastq_maxee;
 extern double opt_fastq_maxee_rate;
 extern double opt_fastq_truncee;
 extern double opt_id;
+extern double opt_lca_cutoff;
 extern double opt_max_unmasked_pct;
 extern double opt_maxid;
 extern double opt_maxqt;
