@@ -72,17 +72,19 @@ class xstring
     {
       length = 0;
       alloc = 0;
-      string = 0;
+      string = nullptr;
     }
 
   ~xstring()
-    {
-      if (alloc > 0)
+  {
+    if (alloc > 0)
+      {
         xfree(string);
-      alloc = 0;
-      string = 0;
-      length = 0;
-    }
+      }
+    alloc = 0;
+    string = nullptr;
+    length = 0;
+  }
 
   void empty()
   {
@@ -92,9 +94,13 @@ class xstring
   char * get_string()
   {
     if (length > 0)
-      return string;
+      {
+        return string;
+      }
     else
-      return empty_string;
+      {
+        return empty_string;
+      }
   }
 
   size_t get_length()
@@ -117,9 +123,12 @@ class xstring
 
   void add_d(int d)
   {
-    int needed = snprintf(0, 0, "%d", d);
+    int needed = snprintf(nullptr, 0, "%d", d);
     if (needed < 0)
-      fatal("snprintf failed");
+      {
+        fatal("snprintf failed");
+      }
+
     if (length + needed + 1 > alloc)
       {
         alloc = length + needed + 1;
